| 限定符和类型 | 方法和说明 |
|---|---|
static boolean |
AuthorityChecker.check(String username,
List<? extends PartialPath> paths,
Operator.OperatorType type,
String targetUser)
check permission.
|
| 限定符和类型 | 方法和说明 |
|---|---|
boolean |
BasicAuthorizer.checkUserPrivileges(String username,
String path,
int privilegeId) |
boolean |
OpenIdAuthorizer.checkUserPrivileges(String username,
String path,
int privilegeId) |
boolean |
IAuthorizer.checkUserPrivileges(String username,
String path,
int privilegeId)
Check if the user have the privilege on the seriesPath.
|
void |
BasicAuthorizer.createRole(String roleName) |
void |
IAuthorizer.createRole(String roleName)
Add a role.
|
void |
BasicAuthorizer.createUser(String username,
String password) |
void |
IAuthorizer.createUser(String username,
String password)
Create a user with given username and password.
|
void |
BasicAuthorizer.deleteRole(String roleName) |
void |
IAuthorizer.deleteRole(String roleName)
Delete a role.
|
void |
BasicAuthorizer.deleteUser(String username) |
void |
IAuthorizer.deleteUser(String username)
Delete a user.
|
static IAuthorizer |
BasicAuthorizer.getInstance()
function for getting the instance of the local file authorizer.
|
Set<Integer> |
BasicAuthorizer.getPrivileges(String username,
String path) |
Set<Integer> |
IAuthorizer.getPrivileges(String username,
String path)
Get the all the privileges of a user on a seriesPath.
|
Role |
BasicAuthorizer.getRole(String roleName) |
Role |
IAuthorizer.getRole(String roleName)
Find a role by its name.
|
User |
BasicAuthorizer.getUser(String username) |
User |
IAuthorizer.getUser(String username)
Find a user by its name.
|
void |
BasicAuthorizer.grantPrivilegeToRole(String roleName,
String path,
int privilegeId) |
void |
IAuthorizer.grantPrivilegeToRole(String roleName,
String path,
int privilegeId)
Add a privilege on a seriesPath to a role.
|
void |
BasicAuthorizer.grantPrivilegeToUser(String username,
String path,
int privilegeId) |
void |
IAuthorizer.grantPrivilegeToUser(String username,
String path,
int privilegeId)
Grant a privilege on a seriesPath to a user.
|
void |
BasicAuthorizer.grantRoleToUser(String roleName,
String username) |
void |
IAuthorizer.grantRoleToUser(String roleName,
String username)
Add a role to a user.
|
protected void |
BasicAuthorizer.init() |
boolean |
BasicAuthorizer.isUserUseWaterMark(String userName) |
boolean |
IAuthorizer.isUserUseWaterMark(String userName)
Whether data water-mark is enabled for user 'userName'.
|
boolean |
BasicAuthorizer.login(String username,
String password) |
boolean |
OpenIdAuthorizer.login(String token,
String password) |
boolean |
IAuthorizer.login(String username,
String password)
Login for a user.
|
void |
BasicAuthorizer.replaceAllRoles(Map<String,Role> roles) |
void |
IAuthorizer.replaceAllRoles(Map<String,Role> roles)
clear all old roles info, replace the old roles with the new one
|
void |
BasicAuthorizer.replaceAllUsers(Map<String,User> users) |
void |
IAuthorizer.replaceAllUsers(Map<String,User> users)
clear all old users info, replace the old users with the new one
|
void |
BasicAuthorizer.reset() |
void |
IAuthorizer.reset()
Reset the Authorizer to initiative status.
|
void |
BasicAuthorizer.revokePrivilegeFromRole(String roleName,
String path,
int privilegeId) |
void |
IAuthorizer.revokePrivilegeFromRole(String roleName,
String path,
int privilegeId)
Remove a privilege on a seriesPath from a role.
|
void |
BasicAuthorizer.revokePrivilegeFromUser(String username,
String path,
int privilegeId) |
void |
IAuthorizer.revokePrivilegeFromUser(String username,
String path,
int privilegeId)
Revoke a privilege on seriesPath from a user.
|
void |
BasicAuthorizer.revokeRoleFromUser(String roleName,
String username) |
void |
IAuthorizer.revokeRoleFromUser(String roleName,
String username)
Revoke a role from a user.
|
void |
BasicAuthorizer.setUserUseWaterMark(String userName,
boolean useWaterMark) |
void |
IAuthorizer.setUserUseWaterMark(String userName,
boolean useWaterMark)
Enable or disable data water-mark for user 'userName'.
|
void |
BasicAuthorizer.updateUserPassword(String username,
String newPassword) |
void |
IAuthorizer.updateUserPassword(String username,
String newPassword)
Modify the password of a user.
|
| 构造器和说明 |
|---|
LocalFileAuthorizer() |
OpenIdAuthorizer() |
| 限定符和类型 | 方法和说明 |
|---|---|
boolean |
IRoleManager.createRole(String rolename)
Create a role with given rolename.
|
boolean |
BasicRoleManager.createRole(String rolename) |
boolean |
IRoleManager.deleteRole(String rolename)
Delete a role.
|
boolean |
BasicRoleManager.deleteRole(String rolename) |
Role |
IRoleManager.getRole(String rolename)
Get a role object.
|
Role |
BasicRoleManager.getRole(String rolename) |
boolean |
IRoleManager.grantPrivilegeToRole(String rolename,
String path,
int privilegeId)
Grant a privilege on a seriesPath to a role.
|
boolean |
BasicRoleManager.grantPrivilegeToRole(String rolename,
String path,
int privilegeId) |
void |
IRoleManager.replaceAllRoles(Map<String,Role> roles)
clear all old roles info, replace the old roles with the new one.
|
void |
BasicRoleManager.replaceAllRoles(Map<String,Role> roles) |
boolean |
IRoleManager.revokePrivilegeFromRole(String rolename,
String path,
int privilegeId)
Revoke a privilege on seriesPath from a role.
|
boolean |
BasicRoleManager.revokePrivilegeFromRole(String rolename,
String path,
int privilegeId) |
| 限定符和类型 | 方法和说明 |
|---|---|
boolean |
IUserManager.createUser(String username,
String password)
Create a user with given username and password.
|
boolean |
BasicUserManager.createUser(String username,
String password) |
boolean |
IUserManager.deleteUser(String username)
Delete a user.
|
boolean |
BasicUserManager.deleteUser(String username) |
User |
IUserManager.getUser(String username)
Get a user object.
|
User |
BasicUserManager.getUser(String username) |
boolean |
IUserManager.grantPrivilegeToUser(String username,
String path,
int privilegeId)
Grant a privilege on a seriesPath to a user.
|
boolean |
BasicUserManager.grantPrivilegeToUser(String username,
String path,
int privilegeId) |
boolean |
IUserManager.grantRoleToUser(String roleName,
String username)
Add a role to a user.
|
boolean |
BasicUserManager.grantRoleToUser(String roleName,
String username) |
boolean |
IUserManager.isUserUseWaterMark(String userName)
Whether data water-mark is enabled for user 'userName'.
|
boolean |
BasicUserManager.isUserUseWaterMark(String username) |
void |
IUserManager.replaceAllUsers(Map<String,User> users)
clear all old users info, replace the old users with the new one.
|
void |
BasicUserManager.replaceAllUsers(Map<String,User> users) |
void |
IUserManager.reset()
Re-initialize this object.
|
void |
BasicUserManager.reset() |
boolean |
IUserManager.revokePrivilegeFromUser(String username,
String path,
int privilegeId)
Revoke a privilege on seriesPath from a user.
|
boolean |
BasicUserManager.revokePrivilegeFromUser(String username,
String path,
int privilegeId) |
boolean |
IUserManager.revokeRoleFromUser(String roleName,
String username)
Revoke a role from a user.
|
boolean |
BasicUserManager.revokeRoleFromUser(String roleName,
String username) |
void |
IUserManager.setUserUseWaterMark(String userName,
boolean useWaterMark)
Enable or disable data water-mark for user 'userName'.
|
void |
BasicUserManager.setUserUseWaterMark(String username,
boolean useWaterMark) |
boolean |
IUserManager.updateUserPassword(String username,
String newPassword)
Modify the password of a user.
|
boolean |
BasicUserManager.updateUserPassword(String username,
String newPassword) |
| 构造器和说明 |
|---|
BasicUserManager(IUserAccessor accessor)
BasicUserManager Constructor.
|
LocalFileUserManager(String userDirPath) |
| 构造器和说明 |
|---|
AuthorizationFilter() |
| 构造器和说明 |
|---|
AuthorPlan(AuthorOperator.AuthorType authorType,
String userName,
String roleName,
String password,
String newPassword,
String[] authorizationList,
PartialPath nodeName)
AuthorPlan Constructor.
|
| 限定符和类型 | 方法和说明 |
|---|---|
boolean |
ServiceProvider.checkAuthorization(PhysicalPlan plan,
String username) |
| 限定符和类型 | 方法和说明 |
|---|---|
static void |
AuthUtils.validatePassword(String password)
validate password size.
|
static void |
AuthUtils.validatePath(String path)
validate series path.
|
static void |
AuthUtils.validatePrivilege(int privilegeId)
validate privilege.
|
static void |
AuthUtils.validatePrivilegeOnPath(String path,
int privilegeId)
validate privilege on path.
|
static void |
AuthUtils.validateRolename(String rolename)
validate role name.
|
static void |
AuthUtils.validateUsername(String username)
validate username.
|
Copyright © 2022 The Apache Software Foundation. All rights reserved.