| 程序包 | 说明 |
|---|---|
| org.apache.iotdb.db.auth.authorizer | |
| org.apache.iotdb.db.auth.role |
| 限定符和类型 | 方法和说明 |
|---|---|
Role |
BasicAuthorizer.getRole(String roleName) |
Role |
IAuthorizer.getRole(String roleName)
Find a role by its name.
|
| 限定符和类型 | 方法和说明 |
|---|---|
Map<String,Role> |
BasicAuthorizer.getAllRoles() |
Map<String,Role> |
IAuthorizer.getAllRoles()
get all role
|
| 限定符和类型 | 方法和说明 |
|---|---|
void |
BasicAuthorizer.replaceAllRoles(Map<String,Role> roles) |
void |
IAuthorizer.replaceAllRoles(Map<String,Role> roles)
clear all old roles info, replace the old roles with the new one
|
| 限定符和类型 | 方法和说明 |
|---|---|
Role |
IRoleManager.getRole(String rolename)
Get a role object.
|
Role |
BasicRoleManager.getRole(String rolename) |
Role |
LocalFileRoleAccessor.loadRole(String rolename) |
Role |
IRoleAccessor.loadRole(String rolename)
Deserialize a role from lower storage.
|
| 限定符和类型 | 方法和说明 |
|---|---|
void |
LocalFileRoleAccessor.saveRole(Role role) |
void |
IRoleAccessor.saveRole(Role role)
Serialize the role object to lower storage.
|
| 限定符和类型 | 方法和说明 |
|---|---|
void |
IRoleManager.replaceAllRoles(Map<String,Role> roles)
clear all old roles info, replace the old roles with the new one.
|
void |
BasicRoleManager.replaceAllRoles(Map<String,Role> roles) |
Copyright © 2022 The Apache Software Foundation. All rights reserved.