| 程序包 | 说明 |
|---|---|
| org.apache.iotdb.db.auth.authorizer | |
| org.apache.iotdb.db.auth.entity | |
| org.apache.iotdb.db.auth.role | |
| org.apache.iotdb.db.auth.user | |
| org.apache.iotdb.db.utils |
| 类和说明 |
|---|
| Role
This class contains all information of a role.
|
| User
This class contains all information of a User.
|
| 类和说明 |
|---|
| PathPrivilege
This class represents a privilege on a specific seriesPath.
|
| PrivilegeType
This enum class contains all available privileges in IoTDB.
|
| 类和说明 |
|---|
| Role
This class contains all information of a role.
|
| 类和说明 |
|---|
| User
This class contains all information of a User.
|
| 类和说明 |
|---|
| PathPrivilege
This class represents a privilege on a specific seriesPath.
|
Copyright © 2022 The Apache Software Foundation. All rights reserved.