| 接口 | 说明 |
|---|---|
| IRoleAccessor |
This interface manages the serialization/deserialization of the role objects.
|
| IRoleManager |
This interface maintains roles in memory and is responsible for their modifications.
|
| 类 | 说明 |
|---|---|
| BasicRoleManager |
This class reads roles from local files through LocalFileRoleAccessor and manages them in a hash
map.
|
| LocalFileRoleAccessor |
This class store each role in a separate sequential file.
|
| LocalFileRoleManager |
Copyright © 2022 The Apache Software Foundation. All rights reserved.