| 程序包 | 说明 |
|---|---|
| org.apache.iotdb.db.auth.role |
| 类和说明 |
|---|
| BasicRoleManager
This class reads roles from local files through LocalFileRoleAccessor and manages them in a hash
map.
|
| IRoleAccessor
This interface manages the serialization/deserialization of the role objects.
|
| IRoleManager
This interface maintains roles in memory and is responsible for their modifications.
|
Copyright © 2022 The Apache Software Foundation. All rights reserved.