public interface IUserAccessor
| 限定符和类型 | 方法和说明 |
|---|---|
boolean |
deleteUser(String username)
Delete a user's from lower storage.
|
List<String> |
listAllUsers()
List all users existing in the database.
|
User |
loadUser(String username)
Deserialize a user from lower storage.
|
void |
reset()
Re-initialize this object.
|
void |
saveUser(User user)
Serialize the user object to lower storage.
|
User loadUser(String username) throws IOException
username - The name of the user to be deserialized.IOException - if an exception is raised when interacting with the lower storage.void saveUser(User user) throws IOException
user - The user object that is to be saved.IOException - if an exception is raised when interacting with the lower storage.boolean deleteUser(String username) throws IOException
username - The name of the user to be deleted.IOException - if an exception is raised when interacting with the lower storage.List<String> listAllUsers()
void reset()
Copyright © 2022 The Apache Software Foundation. All rights reserved.