| 程序包 | 说明 |
|---|---|
| org.apache.iotdb.db.auth.user |
| 限定符和类型 | 类和说明 |
|---|---|
class |
BasicUserManager
This class stores information of each user in a separate file within a directory, and cache them
in memory when a user is accessed.
|
class |
LocalFileUserManager |
Copyright © 2022 The Apache Software Foundation. All rights reserved.