| 接口 | 说明 |
|---|---|
| IUserAccessor |
This interface manages the serialization/deserialization of the user objects.
|
| IUserManager |
This interface provides accesses to users.
|
| 类 | 说明 |
|---|---|
| BasicUserManager |
This class stores information of each user in a separate file within a directory, and cache them
in memory when a user is accessed.
|
| LocalFileUserAccessor |
This class loads a user's information from the corresponding file.The user file is a sequential
file.
|
| LocalFileUserManager |
Copyright © 2022 The Apache Software Foundation. All rights reserved.