| 程序包 | 说明 |
|---|---|
| org.apache.iotdb.db.auth.user |
| 类和说明 |
|---|
| BasicUserManager
This class stores information of each user in a separate file within a directory, and cache them
in memory when a user is accessed.
|
| IUserAccessor
This interface manages the serialization/deserialization of the user objects.
|
| IUserManager
This interface provides accesses to users.
|
Copyright © 2022 The Apache Software Foundation. All rights reserved.