| 类 | 说明 |
|---|---|
| HashLock |
This class manages an array of locks and use the hash code of an object as an index of the array
to find the corresponding lock, so that the operations on the same key (string) can be prevented
while the number of locks remain controlled.
|
| IoTDBDaemonThreadFactory | |
| IoTDBDefaultThreadExceptionHandler | |
| IoTDBThreadPoolFactory |
This class is used to create thread pool which must contain the pool name.
|
| IoTThreadFactory | |
| WrappedRunnable |
| 枚举 | 说明 |
|---|---|
| ThreadName |
Copyright © 2022 The Apache Software Foundation. All rights reserved.