| 类 | 说明 |
|---|---|
| CompactionMetricsManager | |
| CompactionScheduler |
CompactionScheduler schedules and submits the compaction task periodically, and it counts the
total number of running compaction task.
|
| CompactionTaskComparator | |
| CompactionTaskManager |
CompactionMergeTaskPoolManager provides a ThreadPool tPro queue and run all compaction tasks.
|
| CompactionUtils |
This tool can be used to perform inner space or cross space compaction of aligned and non aligned
timeseries .
|
| TsFileIdentifier |
This class record the logical information of files in compaction, which is used to locate file in
disk.
|
Copyright © 2022 The Apache Software Foundation. All rights reserved.