| 程序包 | 说明 |
|---|---|
| org.apache.iotdb.db.engine.compaction | |
| org.apache.iotdb.db.engine.compaction.utils.log |
| 类和说明 |
|---|
| CompactionTaskManager
CompactionMergeTaskPoolManager provides a ThreadPool tPro queue and run all compaction tasks.
|
| TsFileIdentifier
This class record the logical information of files in compaction, which is used to locate file in
disk.
|
| 类和说明 |
|---|
| TsFileIdentifier
This class record the logical information of files in compaction, which is used to locate file in
disk.
|
Copyright © 2022 The Apache Software Foundation. All rights reserved.