| 接口 | 说明 |
|---|---|
| CloseFileListener | |
| FlushListener | |
| FlushManagerMBean | |
| TsFileFlushPolicy |
TsFileFlushPolicy is applied when a TsFileProcessor is full after insertion.
|
| 类 | 说明 |
|---|---|
| FlushListener.EmptyListener | |
| FlushManager | |
| MemTableFlushTask |
flush task to flush one memtable using a pipeline model to flush, which is sort memtable ->
encoding -> write to disk (io task)
|
| NotifyFlushMemTable |
Only used in sync flush and async close to start a flush task This memtable is not managed by
MemTablePool and does not store any data.
|
| TsFileFlushPolicy.DirectFlushPolicy |
Copyright © 2022 The Apache Software Foundation. All rights reserved.