public class AlignedWritableMemChunk extends Object implements IWritableMemChunk
| 构造器和说明 |
|---|
AlignedWritableMemChunk(List<IMeasurementSchema> schemaList) |
| 限定符和类型 | 方法和说明 |
|---|---|
long |
alignedListSize() |
boolean |
containsMeasurement(String measurementId) |
long |
count() |
IChunkWriter |
createIChunkWriter() |
int |
delete(long lowerBound,
long upperBound) |
Pair<Integer,Boolean> |
deleteDataFromAColumn(long lowerBound,
long upperBound,
String measurementId) |
void |
encode(IChunkWriter chunkWriter) |
Set<String> |
getAllMeasurements() |
long |
getFirstPoint() |
long |
getLastPoint() |
IMeasurementSchema |
getSchema() |
TVList |
getSortedTvListForQuery()
served for query requests.
|
TVList |
getSortedTvListForQuery(List<IMeasurementSchema> schemaList)
served for vector query requests.
|
TVList |
getTVList() |
void |
putAlignedValue(long t,
Object[] v,
int[] columnIndexArray) |
void |
putAlignedValues(long[] t,
Object[] v,
BitMap[] bitMaps,
int[] columnIndexArray,
int start,
int end) |
void |
putBinaries(long[] t,
Binary[] v,
BitMap bitMap,
int start,
int end) |
void |
putBinary(long t,
Binary v) |
void |
putBoolean(long t,
boolean v) |
void |
putBooleans(long[] t,
boolean[] v,
BitMap bitMap,
int start,
int end) |
void |
putDouble(long t,
double v) |
void |
putDoubles(long[] t,
double[] v,
BitMap bitMap,
int start,
int end) |
void |
putFloat(long t,
float v) |
void |
putFloats(long[] t,
float[] v,
BitMap bitMap,
int start,
int end) |
void |
putInt(long t,
int v) |
void |
putInts(long[] t,
int[] v,
BitMap bitMap,
int start,
int end) |
void |
putLong(long t,
long v) |
void |
putLongs(long[] t,
long[] v,
BitMap bitMap,
int start,
int end) |
void |
release() |
void |
removeColumn(String measurementId) |
void |
sortTvListForFlush()
served for flush requests.
|
void |
write(long[] times,
Object valueList,
BitMap bitMap,
TSDataType dataType,
int start,
int end)
write data in the range [start, end).
|
void |
write(long insertTime,
Object objectValue) |
void |
writeAlignedValue(long insertTime,
Object[] objectValue,
List<Integer> failedIndices,
List<IMeasurementSchema> schemaList) |
void |
writeAlignedValues(long[] times,
Object[] valueList,
BitMap[] bitMaps,
List<Integer> failedIndices,
List<IMeasurementSchema> schemaList,
int start,
int end) |
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitgetMinTimepublic AlignedWritableMemChunk(List<IMeasurementSchema> schemaList)
public boolean containsMeasurement(String measurementId)
public void putLong(long t,
long v)
putLong 在接口中 IWritableMemChunkpublic void putInt(long t,
int v)
putInt 在接口中 IWritableMemChunkpublic void putFloat(long t,
float v)
putFloat 在接口中 IWritableMemChunkpublic void putDouble(long t,
double v)
putDouble 在接口中 IWritableMemChunkpublic void putBinary(long t,
Binary v)
putBinary 在接口中 IWritableMemChunkpublic void putBoolean(long t,
boolean v)
putBoolean 在接口中 IWritableMemChunkpublic void putAlignedValue(long t,
Object[] v,
int[] columnIndexArray)
putAlignedValue 在接口中 IWritableMemChunkpublic void putLongs(long[] t,
long[] v,
BitMap bitMap,
int start,
int end)
putLongs 在接口中 IWritableMemChunkpublic void putInts(long[] t,
int[] v,
BitMap bitMap,
int start,
int end)
putInts 在接口中 IWritableMemChunkpublic void putFloats(long[] t,
float[] v,
BitMap bitMap,
int start,
int end)
putFloats 在接口中 IWritableMemChunkpublic void putDoubles(long[] t,
double[] v,
BitMap bitMap,
int start,
int end)
putDoubles 在接口中 IWritableMemChunkpublic void putBinaries(long[] t,
Binary[] v,
BitMap bitMap,
int start,
int end)
putBinaries 在接口中 IWritableMemChunkpublic void putBooleans(long[] t,
boolean[] v,
BitMap bitMap,
int start,
int end)
putBooleans 在接口中 IWritableMemChunkpublic void putAlignedValues(long[] t,
Object[] v,
BitMap[] bitMaps,
int[] columnIndexArray,
int start,
int end)
putAlignedValues 在接口中 IWritableMemChunkpublic void write(long insertTime,
Object objectValue)
write 在接口中 IWritableMemChunkpublic void writeAlignedValue(long insertTime,
Object[] objectValue,
List<Integer> failedIndices,
List<IMeasurementSchema> schemaList)
writeAlignedValue 在接口中 IWritableMemChunkpublic void write(long[] times,
Object valueList,
BitMap bitMap,
TSDataType dataType,
int start,
int end)
IWritableMemChunkwrite 在接口中 IWritableMemChunkpublic void writeAlignedValues(long[] times,
Object[] valueList,
BitMap[] bitMaps,
List<Integer> failedIndices,
List<IMeasurementSchema> schemaList,
int start,
int end)
writeAlignedValues 在接口中 IWritableMemChunkpublic TVList getTVList()
getTVList 在接口中 IWritableMemChunkpublic long count()
count 在接口中 IWritableMemChunkpublic long alignedListSize()
public IMeasurementSchema getSchema()
getSchema 在接口中 IWritableMemChunkpublic TVList getSortedTvListForQuery()
IWritableMemChunkif tv list has been sorted, just return reference of it
if tv list hasn't been sorted and has no reference, sort and return reference of it
if tv list hasn't been sorted and has reference we should copy and sort it, then return ths list
the mechanism is just like copy on write
This interface should be synchronized for concurrent with sortTvListForFlush
getSortedTvListForQuery 在接口中 IWritableMemChunkpublic TVList getSortedTvListForQuery(List<IMeasurementSchema> schemaList)
IWritableMemChunkthe mechanism is just like copy on write
This interface should be synchronized for concurrent with sortTvListForFlush
getSortedTvListForQuery 在接口中 IWritableMemChunkpublic void sortTvListForFlush()
IWritableMemChunkThis interface should be synchronized for concurrent with getSortedTvListForQuery
sortTvListForFlush 在接口中 IWritableMemChunkpublic int delete(long lowerBound,
long upperBound)
delete 在接口中 IWritableMemChunkpublic Pair<Integer,Boolean> deleteDataFromAColumn(long lowerBound, long upperBound, String measurementId)
public void removeColumn(String measurementId)
public IChunkWriter createIChunkWriter()
createIChunkWriter 在接口中 IWritableMemChunkpublic void encode(IChunkWriter chunkWriter)
encode 在接口中 IWritableMemChunkpublic void release()
release 在接口中 IWritableMemChunkpublic long getFirstPoint()
getFirstPoint 在接口中 IWritableMemChunkpublic long getLastPoint()
getLastPoint 在接口中 IWritableMemChunkCopyright © 2022 The Apache Software Foundation. All rights reserved.