public interface IMemTable
| 限定符和类型 | 方法和说明 |
|---|---|
void |
addTextDataSize(long textDataIncrement)
only used when mem control enabled
|
void |
addTVListRamCost(long cost)
only used when mem control enabled
|
boolean |
checkIfChunkDoesNotExist(IDeviceID deviceId,
String measurement)
must guarantee the device exists in the work memtable only used when mem control enabled
|
void |
clear()
putBack all the memory resources.
|
IMemTable |
copy()
Make a copy of this MemTable.
|
void |
delete(PartialPath path,
PartialPath devicePath,
long startTimestamp,
long endTimestamp)
Delete data in it whose timestamp <= 'timestamp' and belonging to timeseries path.
|
long |
getCreatedTime() |
long |
getCurrentTVListSize(IDeviceID deviceId,
String measurement)
only used when mem control enabled
|
long |
getMaxPlanIndex() |
Map<IDeviceID,IWritableMemChunkGroup> |
getMemTableMap() |
long |
getMinPlanIndex() |
int |
getSeriesNumber() |
long |
getTotalPointsNum() |
long |
getTVListsRamCost()
only used when mem control enabled
|
void |
insert(InsertRowPlan insertRowPlan)
insert into this memtable
|
void |
insertAlignedRow(InsertRowPlan insertRowPlan) |
void |
insertAlignedTablet(InsertTabletPlan insertTabletPlan,
int start,
int end) |
void |
insertTablet(InsertTabletPlan insertTabletPlan,
int start,
int end)
insert tablet into this memtable.
|
boolean |
isEmpty() |
boolean |
isSignalMemTable() |
long |
memSize() |
ReadOnlyMemChunk |
query(PartialPath fullPath,
long ttlLowerBound,
List<Pair<Modification,IMemTable>> modsToMemtable) |
boolean |
reachTotalPointNumThreshold()
only used when mem control enabled
|
void |
release()
release resource of this memtable
|
void |
releaseTextDataSize(long textDataDecrement)
only used when mem control enabled
|
void |
releaseTVListRamCost(long cost)
only used when mem control enabled
|
void |
setShouldFlush() |
boolean |
shouldFlush() |
long |
size() |
void |
write(IDeviceID deviceId,
List<Integer> failedIndices,
List<IMeasurementSchema> schemaList,
long insertTime,
Object[] objectValue) |
void |
write(InsertTabletPlan insertTabletPlan,
int start,
int end)
write data in the range [start, end).
|
void |
writeAlignedRow(IDeviceID deviceId,
List<Integer> failedIndices,
List<IMeasurementSchema> schemaList,
long insertTime,
Object[] objectValue) |
void |
writeAlignedTablet(InsertTabletPlan insertTabletPlan,
int start,
int end) |
Map<IDeviceID,IWritableMemChunkGroup> getMemTableMap()
void write(IDeviceID deviceId, List<Integer> failedIndices, List<IMeasurementSchema> schemaList, long insertTime, Object[] objectValue)
void writeAlignedRow(IDeviceID deviceId, List<Integer> failedIndices, List<IMeasurementSchema> schemaList, long insertTime, Object[] objectValue)
void write(InsertTabletPlan insertTabletPlan, int start, int end)
void writeAlignedTablet(InsertTabletPlan insertTabletPlan, int start, int end)
long size()
long memSize()
void addTVListRamCost(long cost)
void releaseTVListRamCost(long cost)
long getTVListsRamCost()
boolean reachTotalPointNumThreshold()
int getSeriesNumber()
long getTotalPointsNum()
void insert(InsertRowPlan insertRowPlan)
insertRowPlan - insertRowPlanvoid insertAlignedRow(InsertRowPlan insertRowPlan)
void insertTablet(InsertTabletPlan insertTabletPlan, int start, int end) throws WriteProcessException
insertTabletPlan - insertTabletPlanstart - includedend - excludedWriteProcessExceptionvoid insertAlignedTablet(InsertTabletPlan insertTabletPlan, int start, int end) throws WriteProcessException
ReadOnlyMemChunk query(PartialPath fullPath, long ttlLowerBound, List<Pair<Modification,IMemTable>> modsToMemtable) throws IOException, QueryProcessException, MetadataException
void clear()
boolean isEmpty()
void delete(PartialPath path, PartialPath devicePath, long startTimestamp, long endTimestamp)
path - the PartialPath the timeseries to be deleted.devicePath - the device path of the timeseries to be deleted.startTimestamp - the lower-bound of deletion time.endTimestamp - the upper-bound of deletion timeIMemTable copy()
boolean isSignalMemTable()
void setShouldFlush()
boolean shouldFlush()
void release()
boolean checkIfChunkDoesNotExist(IDeviceID deviceId, String measurement)
long getCurrentTVListSize(IDeviceID deviceId, String measurement)
void addTextDataSize(long textDataIncrement)
void releaseTextDataSize(long textDataDecrement)
long getMaxPlanIndex()
long getMinPlanIndex()
long getCreatedTime()
Copyright © 2022 The Apache Software Foundation. All rights reserved.