| 接口 | 说明 |
|---|---|
| ModificationReader |
ModificationReader reads all modifications from a persistent medium like file system.
|
| ModificationWriter |
ModificationWriter provides methods for writing a modification to a persistent medium like file
system.
|
| 类 | 说明 |
|---|---|
| LocalTextModificationAccessor |
LocalTextModificationAccessor uses a file on local file system to store the modifications in text
format, and writes modifications by appending to the tail of the file.
|
Copyright © 2022 The Apache Software Foundation. All rights reserved.