| 程序包 | 说明 |
|---|---|
| org.apache.iotdb.db.engine.modification.io |
| 类和说明 |
|---|
| ModificationReader
ModificationReader reads all modifications from a persistent medium like file system.
|
| ModificationWriter
ModificationWriter provides methods for writing a modification to a persistent medium like file
system.
|
Copyright © 2022 The Apache Software Foundation. All rights reserved.