| 类和说明 |
|---|
| Modification
Modification represents an UPDATE or DELETE operation on a certain timeseries.
|
| 类和说明 |
|---|
| ModificationFile
ModificationFile stores the Modifications of a TsFile or unseq file in another file in the same
directory.
|
| 类和说明 |
|---|
| Modification
Modification represents an UPDATE or DELETE operation on a certain timeseries.
|
| 类和说明 |
|---|
| Modification
Modification represents an UPDATE or DELETE operation on a certain timeseries.
|
| Modification.Type |
| ModificationFile
ModificationFile stores the Modifications of a TsFile or unseq file in another file in the same
directory.
|
| 类和说明 |
|---|
| Modification
Modification represents an UPDATE or DELETE operation on a certain timeseries.
|
| 类和说明 |
|---|
| Deletion
Deletion is a delete operation on a timeseries.
|
| ModificationFile
ModificationFile stores the Modifications of a TsFile or unseq file in another file in the same
directory.
|
| 类和说明 |
|---|
| Modification
Modification represents an UPDATE or DELETE operation on a certain timeseries.
|
| 类和说明 |
|---|
| Modification
Modification represents an UPDATE or DELETE operation on a certain timeseries.
|
| ModificationFile
ModificationFile stores the Modifications of a TsFile or unseq file in another file in the same
directory.
|
| 类和说明 |
|---|
| Modification
Modification represents an UPDATE or DELETE operation on a certain timeseries.
|
| 类和说明 |
|---|
| Modification
Modification represents an UPDATE or DELETE operation on a certain timeseries.
|
| 类和说明 |
|---|
| ModificationFile
ModificationFile stores the Modifications of a TsFile or unseq file in another file in the same
directory.
|
Copyright © 2022 The Apache Software Foundation. All rights reserved.