public class TracedBufferedReader extends Reader
BufferedReader, trace the read position by modifying the fill()
method.| 构造器和说明 |
|---|
TracedBufferedReader(Reader in)
Creates a buffering character-input stream that uses a default-sized input buffer.
|
TracedBufferedReader(Reader in,
int sz)
Creates a buffering character-input stream that uses an input buffer of the specified size.
|
public TracedBufferedReader(Reader in, int sz)
in - A Readersz - Input-buffer sizeIllegalArgumentException - If sz <= 0public TracedBufferedReader(Reader in)
in - A Readerpublic int read()
throws IOException
read 在类中 ReaderIOExceptionpublic int read(char[] cbuf,
int off,
int len)
throws IOException
read 在类中 ReaderIOExceptionpublic String readLine() throws IOException
IOExceptionpublic long skip(long n)
throws IOException
skip 在类中 ReaderIOExceptionpublic boolean ready()
throws IOException
ready 在类中 ReaderIOExceptionpublic boolean markSupported()
markSupported 在类中 Readerpublic void mark(int readAheadLimit)
throws IOException
mark 在类中 ReaderIOExceptionpublic void reset()
throws IOException
reset 在类中 ReaderIOExceptionpublic void close()
throws IOException
close 在接口中 Closeableclose 在接口中 AutoCloseableclose 在类中 ReaderIOExceptionpublic long position()
Copyright © 2022 The Apache Software Foundation. All rights reserved.