| 接口 | 说明 |
|---|---|
| ILastFlushTimeManager |
This interface manages last time and flush time for sequence and unsequence determination
|
| VirtualStorageGroupProcessor.CloseTsFileCallBack | |
| VirtualStorageGroupProcessor.CompactionRecoverCallBack | |
| VirtualStorageGroupProcessor.SettleTsFileCallBack | |
| VirtualStorageGroupProcessor.TimePartitionFilter | |
| VirtualStorageGroupProcessor.UpdateEndTimeCallBack | |
| VirtualStorageGroupProcessor.UpgradeTsFileResourceCallBack |
| 类 | 说明 |
|---|---|
| IDTableFlushTimeManager |
This class manages last time and flush time for sequence and unsequence determination This class
This class is NOT thread safe, caller should ensure synchronization This class not support
upgrade
|
| LastFlushTimeManager |
This class manages last time and flush time for sequence and unsequence determination This class
This class is NOT thread safe, caller should ensure synchronization
|
| StorageGroupInfo |
The storageGroupInfo records the total memory cost of the Storage Group.
|
| TsFileLock |
TsFileLock is a special read-write lock that can be locked by one thread but unlocked by another
thread.
|
| TsFileManager | |
| TsFileNameGenerator | |
| TsFileNameGenerator.TsFileName | |
| TsFileProcessor | |
| TsFileProcessorInfo |
The TsFileProcessorInfo records the memory cost of this TsFileProcessor.
|
| TsFileResource | |
| TsFileResourceList | |
| VirtualStorageGroupProcessor |
For sequence data, a StorageGroupProcessor has some TsFileProcessors, in which there is only one
TsFileProcessor in the working status.
|
| 枚举 | 说明 |
|---|---|
| TsFileResourceStatus |
Copyright © 2022 The Apache Software Foundation. All rights reserved.