| 程序包 | 说明 |
|---|---|
| org.apache.iotdb.db.exception | |
| org.apache.iotdb.db.exception.index | |
| org.apache.iotdb.db.exception.metadata | |
| org.apache.iotdb.db.exception.query |
| 限定符和类型 | 类和说明 |
|---|---|
class |
BatchProcessException |
class |
ConfigurationException |
class |
ContinuousQueryException |
class |
DiskSpaceInsufficientException |
class |
LoadEmptyFileException |
class |
LoadFileException |
class |
MergeException |
class |
PartitionViolationException |
class |
QueryIdNotExsitException |
class |
QueryInBatchStatementException |
class |
ShutdownException |
class |
StartupException |
class |
StorageEngineException |
class |
StorageEngineReadonlyException
the exception when writing to a read-only system
|
class |
StorageGroupNotReadyException |
class |
StorageGroupProcessorException |
class |
SyncConnectionException |
class |
SyncDeviceOwnerConflictException |
class |
SystemCheckException |
class |
TriggerExecutionException |
class |
TriggerManagementException |
class |
TsFileProcessorException |
class |
UDFRegistrationException |
class |
WriteProcessException |
class |
WriteProcessRejectException |
| 构造器和说明 |
|---|
StorageEngineException(IoTDBException e) |
| 限定符和类型 | 类和说明 |
|---|---|
class |
IndexManagerException |
class |
QueryIndexException |
class |
UnsupportedIndexTypeException |
| 构造器和说明 |
|---|
IndexManagerException(IoTDBException e) |
| 限定符和类型 | 类和说明 |
|---|---|
class |
AliasAlreadyExistException |
class |
AlignedTimeseriesException |
class |
DataTypeMismatchException |
class |
DeleteFailedException |
class |
DifferentTemplateException |
class |
DuplicatedTemplateException |
class |
IllegalParameterOfPathException |
class |
IllegalPathException |
class |
MeasurementInsideTemplateException |
class |
MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
class |
MNodeTypeMismatchException |
class |
NoTemplateOnMNodeException |
class |
PathAlreadyExistException |
class |
PathNotExistException |
class |
SeriesNumberOverflowException |
class |
StorageGroupAlreadySetException |
class |
StorageGroupNotSetException |
class |
TemplateImcompatibeException |
class |
TemplateIsInUseException |
class |
UndefinedTemplateException |
| 构造器和说明 |
|---|
MetadataException(IoTDBException exception) |
| 限定符和类型 | 类和说明 |
|---|---|
class |
LogicalOperatorException
This exception is thrown while meeting error in transforming logical operator to physical plan.
|
class |
LogicalOptimizeException
This exception is thrown while meeting error in optimizing logical operator.
|
class |
OutOfTTLException |
class |
PathException |
class |
PathNumOverLimitException |
class |
QueryProcessException |
class |
UnSupportedFillTypeException |
| 构造器和说明 |
|---|
LogicalOperatorException(IoTDBException e) |
LogicalOptimizeException(IoTDBException e) |
QueryProcessException(IoTDBException e) |
Copyright © 2022 The Apache Software Foundation. All rights reserved.