| 限定符和类型 | 方法和说明 |
|---|---|
void |
StorageEngine.delete(PartialPath path,
long startTime,
long endTime,
long planIndex,
VirtualStorageGroupProcessor.TimePartitionFilter timePartitionFilter) |
void |
StorageEngine.deleteTimeseries(PartialPath path,
long planIndex,
VirtualStorageGroupProcessor.TimePartitionFilter timePartitionFilter)
delete data of timeseries "{deviceId}.
|
boolean |
StorageEngine.deleteTsfile(File deletedTsfile) |
boolean |
StorageEngine.deleteTsfileForSync(File deletedTsfile) |
List<String> |
StorageEngine.getLockInfo(List<PartialPath> pathList)
get lock holder for each sg
|
VirtualStorageGroupProcessor |
StorageEngine.getProcessor(PartialPath path)
This method is for insert and query or sth like them, this may get a virtual storage group
|
VirtualStorageGroupProcessor |
StorageEngine.getProcessorDirectly(PartialPath path)
This method is for sync, delete tsfile or sth like them, just get storage group directly by sg
name
|
VirtualStorageGroupProcessor |
StorageEngine.getProcessorDirectly(PartialPath path,
int virtualStorageGroupId)
This method is for sync, delete tsfile or sth like them, just get storage group directly by
virtualStorageGroupId
|
void |
StorageEngine.getResourcesToBeSettled(PartialPath sgPath,
List<TsFileResource> seqResourcesToBeSettled,
List<TsFileResource> unseqResourcesToBeSettled,
List<String> tsFilePaths) |
protected void |
StorageEngine.getSeriesSchemas(InsertPlan insertPlan,
VirtualStorageGroupProcessor processor) |
String |
StorageEngine.getStorageGroupPath(PartialPath path) |
void |
StorageEngine.insert(InsertRowPlan insertRowPlan)
insert an InsertRowPlan to a storage group.
|
void |
StorageEngine.insert(InsertRowsOfOneDevicePlan insertRowsOfOneDevicePlan) |
void |
StorageEngine.insertTablet(InsertTabletPlan insertTabletPlan)
insert a InsertTabletPlan to a storage group
|
void |
StorageEngine.loadNewTsFile(TsFileResource newTsFileResource) |
void |
StorageEngine.loadNewTsFileForSync(TsFileResource newTsFileResource) |
void |
StorageEngine.mergeAll()
merge all storage groups.
|
Pair<List<VirtualStorageGroupProcessor>,Map<VirtualStorageGroupProcessor,List<PartialPath>>> |
StorageEngine.mergeLock(List<PartialPath> pathList)
get all merge lock of the storage group processor related to the query
|
boolean |
StorageEngine.unloadTsfile(File tsfileToBeUnloaded,
File targetDir) |
void |
StorageEngine.upgradeAll()
upgrade all storage groups.
|
| 限定符和类型 | 方法和说明 |
|---|---|
static void |
CompactionUtils.compact(List<TsFileResource> seqFileResources,
List<TsFileResource> unseqFileResources,
List<TsFileResource> targetFileResources) |
| 限定符和类型 | 方法和说明 |
|---|---|
protected void |
ContinuousQuerySchemaCheckTask.doInsert(String sql,
QueryOperator queryOperator,
GroupByTimePlan queryPlan,
QueryDataSet queryDataSet)
we only do some checks here. we don't write any data.
|
protected void |
ContinuousQueryTask.doInsert(String sql,
QueryOperator queryOperator,
GroupByTimePlan queryPlan,
QueryDataSet queryDataSet) |
void |
ContinuousQueryTask.runMayThrow() |
| 限定符和类型 | 方法和说明 |
|---|---|
VirtualStorageGroupProcessor |
StorageGroupManager.getProcessor(int virtualStorageGroupId,
IStorageGroupMNode storageGroupMNode)
get processor from virtualStorageGroupId
|
VirtualStorageGroupProcessor |
StorageGroupManager.getProcessor(PartialPath partialPath,
IStorageGroupMNode storageGroupMNode)
get processor from device id
|
| 限定符和类型 | 方法和说明 |
|---|---|
void |
LocalIoTDBHandler.onEvent(LocalIoTDBEvent event) |
| 限定符和类型 | 类和说明 |
|---|---|
class |
ContinuousQueryException |
class |
DiskSpaceInsufficientException |
class |
StorageEngineReadonlyException
the exception when writing to a read-only system
|
class |
StorageGroupNotReadyException |
class |
TriggerExecutionException |
class |
TriggerManagementException |
| 限定符和类型 | 方法和说明 |
|---|---|
protected QueryDataSet |
PlanExecutor.processDataQuery(QueryPlan queryPlan,
QueryContext context) |
boolean |
PlanExecutor.processNonQuery(PhysicalPlan plan) |
boolean |
IPlanExecutor.processNonQuery(PhysicalPlan plan)
Process Non-Query Physical plan, including insert/update/delete operation of
data/metadata/Privilege
|
QueryDataSet |
PlanExecutor.processQuery(PhysicalPlan queryPlan,
QueryContext context) |
QueryDataSet |
IPlanExecutor.processQuery(PhysicalPlan queryPlan,
QueryContext context)
process query plan of qp layer, construct queryDataSet.
|
| 限定符和类型 | 方法和说明 |
|---|---|
void |
QueryResourceManager.endQuery(long queryId)
Whenever the jdbc request is closed normally or abnormally, this method must be invoked.
|
QueryDataSource |
QueryResourceManager.getQueryDataSource(PartialPath selectedPath,
QueryContext context,
Filter timeFilter,
boolean ascending) |
void |
SessionManager.releaseQueryResource(long queryId) |
| 限定符和类型 | 方法和说明 |
|---|---|
protected AlignedGroupByExecutor |
GroupByWithoutValueFilterDataSet.getAlignedGroupByExecutor(PartialPath path,
QueryContext context,
Filter timeFilter,
TsFileFilter fileFilter,
boolean ascending) |
protected GroupByExecutor |
GroupByWithoutValueFilterDataSet.getGroupByExecutor(PartialPath path,
Set<String> allSensors,
QueryContext context,
Filter timeFilter,
TsFileFilter fileFilter,
boolean ascending) |
protected IReaderByTimestamp |
GroupByWithValueFilterDataSet.getReaderByTime(PartialPath path,
RawDataQueryPlan queryPlan,
QueryContext context) |
protected TimeGenerator |
GroupByWithValueFilterDataSet.getTimeGenerator(QueryContext context,
RawDataQueryPlan queryPlan) |
void |
GroupByWithoutValueFilterDataSet.initGroupBy(QueryContext context,
GroupByTimePlan groupByTimePlan)
init reader and aggregate function.
|
void |
GroupByWithValueFilterDataSet.initGroupBy(QueryContext context,
GroupByTimePlan groupByTimePlan)
init reader and aggregate function.
|
| 构造器和说明 |
|---|
LocalAlignedGroupByExecutor(PartialPath path,
QueryContext context,
Filter timeFilter,
TsFileFilter fileFilter,
boolean ascending) |
LocalGroupByExecutor(PartialPath path,
Set<String> allSensors,
QueryContext context,
Filter timeFilter,
TsFileFilter fileFilter,
boolean ascending) |
| 限定符和类型 | 方法和说明 |
|---|---|
QueryDataSet |
IQueryRouter.aggregate(AggregationPlan aggregationPlan,
QueryContext context)
Execute aggregation query.
|
QueryDataSet |
QueryRouter.aggregate(AggregationPlan aggregationPlan,
QueryContext context) |
protected void |
AggregationExecutor.aggregateOneAlignedSeries(AlignedPath alignedPath,
List<List<Integer>> subIndexes,
Set<String> allMeasurementsInDevice,
Filter timeFilter) |
static void |
AggregationExecutor.aggregateOneAlignedSeries(AlignedPath alignedPath,
Set<String> measurements,
QueryContext context,
Filter timeFilter,
TSDataType tsDataType,
List<List<AggregateResult>> ascAggregateResultList,
List<List<AggregateResult>> descAggregateResultList,
TsFileFilter fileFilter,
boolean ascending) |
protected void |
AggregationExecutor.aggregateOneSeries(PartialPath seriesPath,
List<Integer> indexes,
Set<String> allMeasurementsInDevice,
Filter timeFilter)
get aggregation result for one series
|
static void |
AggregationExecutor.aggregateOneSeries(PartialPath seriesPath,
Set<String> measurements,
QueryContext context,
Filter timeFilter,
TSDataType tsDataType,
List<AggregateResult> ascAggregateResultList,
List<AggregateResult> descAggregateResultList,
TsFileFilter fileFilter,
boolean ascending) |
protected List<Pair<Boolean,TimeValuePair>> |
LastQueryExecutor.calculateLastPairForSeries(List<PartialPath> seriesPaths,
List<TSDataType> dataTypes,
QueryContext context,
IExpression expression,
RawDataQueryPlan lastQueryPlan) |
static List<Pair<Boolean,TimeValuePair>> |
LastQueryExecutor.calculateLastPairForSeriesLocally(List<PartialPath> seriesPaths,
List<TSDataType> dataTypes,
QueryContext context,
IExpression expression,
Map<String,Set<String>> deviceMeasurementsMap) |
protected IFill |
FillQueryExecutor.configureFill(IFill fill,
PartialPath path,
TSDataType dataType,
long queryTime,
Set<String> deviceMeasurements,
QueryContext context) |
QueryDataSet |
FillQueryExecutor.execute(QueryContext context)
execute fill.
|
QueryDataSet |
LastQueryExecutor.execute(QueryContext context,
LastQueryPlan lastQueryPlan)
execute last function
|
QueryDataSet |
RawDataQueryExecutor.executeNonAlign(QueryContext context) |
QueryDataSet |
AggregationExecutor.executeWithoutValueFilter(AggregationPlan aggregationPlan)
execute aggregate function with only time filter or no filter.
|
QueryDataSet |
RawDataQueryExecutor.executeWithoutValueFilter(QueryContext context)
without filter or with global time filter.
|
QueryDataSet |
UDFQueryExecutor.executeWithoutValueFilterAlignByTime(QueryContext context) |
QueryDataSet |
UDFQueryExecutor.executeWithoutValueFilterNonAlign(QueryContext context) |
QueryDataSet |
AggregationExecutor.executeWithValueFilter(AggregationPlan queryPlan)
execute aggregate function with value filter.
|
QueryDataSet |
RawDataQueryExecutor.executeWithValueFilter(QueryContext context)
executeWithValueFilter query.
|
QueryDataSet |
UDFQueryExecutor.executeWithValueFilterAlignByTime(QueryContext context) |
QueryDataSet |
UDFQueryExecutor.executeWithValueFilterNonAlign(QueryContext context) |
QueryDataSet |
IQueryRouter.fill(FillQueryPlan fillQueryPlan,
QueryContext context)
Execute fill query.
|
QueryDataSet |
QueryRouter.fill(FillQueryPlan fillQueryPlan,
QueryContext context) |
protected IReaderByTimestamp |
AggregationExecutor.getReaderByTime(PartialPath path,
RawDataQueryPlan queryPlan,
TSDataType dataType,
QueryContext context) |
protected IReaderByTimestamp |
RawDataQueryExecutor.getReaderByTimestamp(PartialPath path,
Set<String> allSensors,
TSDataType dataType,
QueryContext context) |
protected TimeGenerator |
RawDataQueryExecutor.getTimeGenerator(QueryContext context,
RawDataQueryPlan queryPlan) |
protected TimeGenerator |
AggregationExecutor.getTimeGenerator(QueryContext context,
RawDataQueryPlan queryPlan) |
protected List<TimeValuePair> |
FillQueryExecutor.getTimeValuePairs(QueryContext context) |
QueryDataSet |
IQueryRouter.groupBy(GroupByTimePlan groupByTimePlan,
QueryContext context)
Execute groupBy query.
|
QueryDataSet |
QueryRouter.groupBy(GroupByTimePlan groupByTimePlan,
QueryContext context) |
QueryDataSet |
IQueryRouter.groupByFill(GroupByTimeFillPlan groupByFillPlan,
QueryContext context)
Execute group by fill query
|
QueryDataSet |
QueryRouter.groupByFill(GroupByTimeFillPlan groupByFillPlan,
QueryContext context) |
protected List<ManagedSeriesReader> |
RawDataQueryExecutor.initManagedSeriesReader(QueryContext context) |
protected Pair<List<IReaderByTimestamp>,List<List<Integer>>> |
RawDataQueryExecutor.initSeriesReaderByTimestamp(QueryContext context,
RawDataQueryPlan queryPlan,
List<Boolean> cached,
Filter timeFilter)
init IReaderByTimestamp for each not cached PartialPath, if it's already been cached, the
corresponding IReaderByTimestamp will be null group these not cached PartialPath to one
AlignedPath if they belong to same aligned device
|
QueryDataSet |
IQueryRouter.lastQuery(LastQueryPlan lastQueryPlan,
QueryContext context)
Execute last query
|
QueryDataSet |
QueryRouter.lastQuery(LastQueryPlan lastQueryPlan,
QueryContext context) |
protected QueryDataSet |
RawDataQueryExecutor.needRedirect(QueryContext context,
boolean hasValueFilter)
Check whether need to redirect query to other node.
|
QueryDataSet |
IQueryRouter.rawDataQuery(RawDataQueryPlan queryPlan,
QueryContext context)
Execute physical plan.
|
QueryDataSet |
QueryRouter.rawDataQuery(RawDataQueryPlan queryPlan,
QueryContext context) |
QueryDataSet |
IQueryRouter.udafQuery(UDAFPlan udafPlan,
QueryContext context)
Execute UDAF query.
|
QueryDataSet |
QueryRouter.udafQuery(UDAFPlan udafPlan,
QueryContext context) |
QueryDataSet |
IQueryRouter.udtfQuery(UDTFPlan udtfPlan,
QueryContext context)
Execute UDTF query
|
QueryDataSet |
QueryRouter.udtfQuery(UDTFPlan udtfPlan,
QueryContext context) |
| 限定符和类型 | 方法和说明 |
|---|---|
protected TimeValuePair |
LinearFill.calculatePrecedingPoint() |
protected TimeValuePair |
LinearFill.calculateSucceedingPoint() |
abstract void |
IFill.configureFill(PartialPath path,
TSDataType dataType,
long queryTime,
Set<String> deviceMeasurements,
QueryContext context) |
void |
PreviousFill.configureFill(PartialPath path,
TSDataType dataType,
long queryTime,
Set<String> sensors,
QueryContext context) |
TimeValuePair |
LinearFill.getFillResult() |
abstract TimeValuePair |
IFill.getFillResult() |
TimeValuePair |
PreviousFill.getFillResult() |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
ServerTimeGenerator.serverConstructNode(IExpression expression) |
| 构造器和说明 |
|---|
ServerTimeGenerator(QueryContext context,
RawDataQueryPlan queryPlan)
Constructor of EngineTimeGenerator.
|
| 限定符和类型 | 方法和说明 |
|---|---|
void |
IoTDBMBean.stop() |
| 限定符和类型 | 方法和说明 |
|---|---|
QueryDataSet |
ServiceProvider.createQueryDataSet(QueryContext context,
PhysicalPlan physicalPlan,
int fetchSize)
create QueryDataSet and buffer it for fetchResults
|
abstract boolean |
ServiceProvider.executeNonQuery(PhysicalPlan plan) |
boolean |
StandaloneServiceProvider.executeNonQuery(PhysicalPlan plan) |
Copyright © 2022 The Apache Software Foundation. All rights reserved.