| 程序包 | 说明 |
|---|---|
| org.apache.iotdb.db.sync.sender.transfer |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
ISyncClient.confirmIdentity()
Confirm identity, the receiver will check whether the sender has synchronization privileges.
|
void |
SyncClient.confirmIdentity() |
void |
ISyncClient.establishConnection(String serverIp,
int serverPort)
Establish a connection to receiver end.
|
void |
SyncClient.establishConnection(String serverIp,
int serverPort) |
void |
ISyncClient.sync()
Execute a sync task for a data directory.
|
void |
ISyncClient.syncAll()
Execute a sync task for all data directory.
|
void |
SyncClient.syncAll() |
void |
ISyncClient.syncDataFilesInOneGroup(String sgName,
Long vgId,
Long timeRangeId,
Set<File> toBeSyncFiles)
For new valid files in a storage group, sync them to receiver side and load these data in
receiver.
|
void |
SyncClient.syncDataFilesInOneGroup(String sgName,
Long vgId,
Long timeRangeId,
Set<File> toBeSyncFiles) |
void |
ISyncClient.syncDeletedFilesNameInOneGroup(String sgName,
Long vgId,
Long timeRangeId,
Set<File> deletedFilesName)
For deleted files in a storage group, sync them to receiver side and load these files in
receiver.
|
void |
ISyncClient.syncSchema()
Sync schema file to receiver before all data to be synced.
|
void |
SyncClient.syncSchema() |
Copyright © 2022 The Apache Software Foundation. All rights reserved.