| 程序包 | 说明 |
|---|---|
| org.apache.iotdb.db.sync.receiver.load | |
| org.apache.iotdb.db.sync.sender.transfer |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
FileLoaderManager.checkAndUpdateDeviceOwner(TsFileResource tsFileResource)
Check whether there have conflicts about the device owner.
|
| 限定符和类型 | 方法和说明 |
|---|---|
void |
ISyncClient.syncDataFilesInOneGroup(String sgName,
Long vgId,
Long timeRangeId,
Set<File> toBeSyncFiles)
For new valid files in a storage group, sync them to receiver side and load these data in
receiver.
|
void |
SyncClient.syncDataFilesInOneGroup(String sgName,
Long vgId,
Long timeRangeId,
Set<File> toBeSyncFiles) |
Copyright © 2022 The Apache Software Foundation. All rights reserved.