| 程序包 | 说明 |
|---|---|
| org.apache.iotdb.db.engine | |
| org.apache.iotdb.db.protocol.rest.handler | |
| org.apache.iotdb.db.rescon |
rescon means Resource Control, classes in this package provide global control over various
resources shared in IoTDB.
|
| 限定符和类型 | 方法和说明 |
|---|---|
static void |
StorageEngine.blockInsertionIfReject(TsFileProcessor tsFileProcessor)
block insertion if the insertion is rejected by memory control
|
| 限定符和类型 | 方法和说明 |
|---|---|
static InsertTabletPlan |
PhysicalPlanConstructionHandler.constructInsertTabletPlan(InsertTabletRequest insertTabletRequest) |
| 限定符和类型 | 方法和说明 |
|---|---|
boolean |
SystemInfo.reportStorageGroupStatus(StorageGroupInfo storageGroupInfo,
TsFileProcessor tsFileProcessor)
Report current mem cost of storage group to system.
|
Copyright © 2022 The Apache Software Foundation. All rights reserved.