| 限定符和类型 | 方法和说明 |
|---|---|
protected void |
StorageEngine.getSeriesSchemas(InsertPlan insertPlan,
VirtualStorageGroupProcessor processor) |
void |
StorageEngine.insert(InsertRowPlan insertRowPlan)
insert an InsertRowPlan to a storage group.
|
void |
StorageEngine.insert(InsertRowsOfOneDevicePlan insertRowsOfOneDevicePlan) |
void |
StorageEngine.insertTablet(InsertTabletPlan insertTabletPlan)
insert a InsertTabletPlan to a storage group
|
void |
StorageEngine.loadNewTsFile(TsFileResource newTsFileResource) |
| 限定符和类型 | 方法和说明 |
|---|---|
static void |
CompactionUtils.compact(List<TsFileResource> seqFileResources,
List<TsFileResource> unseqFileResources,
List<TsFileResource> targetFileResources) |
| 限定符和类型 | 方法和说明 |
|---|---|
static void |
InnerSpaceCompactionUtils.compact(TsFileResource targetResource,
List<TsFileResource> tsFileResources) |
| 限定符和类型 | 方法和说明 |
|---|---|
protected void |
ContinuousQuerySchemaCheckTask.doInsert(String sql,
QueryOperator queryOperator,
GroupByTimePlan queryPlan,
QueryDataSet queryDataSet)
we only do some checks here. we don't write any data.
|
protected void |
ContinuousQueryTask.doInsert(String sql,
QueryOperator queryOperator,
GroupByTimePlan queryPlan,
QueryDataSet queryDataSet) |
void |
ContinuousQueryTask.runMayThrow() |
| 限定符和类型 | 方法和说明 |
|---|---|
ReadOnlyMemChunk |
IMemTable.query(PartialPath fullPath,
long ttlLowerBound,
List<Pair<Modification,IMemTable>> modsToMemtable) |
| 限定符和类型 | 类和说明 |
|---|---|
class |
AliasAlreadyExistException |
class |
AlignedTimeseriesException |
class |
DataTypeMismatchException |
class |
DeleteFailedException |
class |
DifferentTemplateException |
class |
DuplicatedTemplateException |
class |
IllegalParameterOfPathException |
class |
IllegalPathException |
class |
MeasurementInsideTemplateException |
class |
MNodeTypeMismatchException |
class |
NoTemplateOnMNodeException |
class |
PathAlreadyExistException |
class |
PathNotExistException |
class |
SeriesNumberOverflowException |
class |
StorageGroupAlreadySetException |
class |
StorageGroupNotSetException |
class |
TemplateImcompatibeException |
class |
TemplateIsInUseException |
class |
UndefinedTemplateException |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
MManager.addAttributes(Map<String,String> attributesMap,
PartialPath fullPath)
add new attributes key-value for the timeseries
|
void |
MManager.addTags(Map<String,String> tagsMap,
PartialPath fullPath)
add new tags key-value for the timeseries
|
void |
MManager.appendSchemaTemplate(AppendTemplatePlan plan) |
void |
MManager.changeAlias(PartialPath path,
String alias) |
void |
MManager.changeOffset(PartialPath path,
long offset)
Check whether the given path contains a storage group change or set the new offset of a
timeseries
|
int |
MManager.countMeasurementsInTemplate(String templateName) |
void |
MManager.createAlignedTimeSeries(CreateAlignedTimeSeriesPlan plan)
create aligned timeseries
|
void |
MManager.createAlignedTimeSeries(PartialPath prefixPath,
List<String> measurements,
List<TSDataType> dataTypes,
List<TSEncoding> encodings,
List<CompressionType> compressors) |
void |
MManager.createSchemaTemplate(CreateTemplatePlan plan) |
void |
MManager.createTimeseries(CreateTimeSeriesPlan plan) |
void |
MManager.createTimeseries(CreateTimeSeriesPlan plan,
long offset) |
void |
MManager.createTimeseries(PartialPath path,
TSDataType dataType,
TSEncoding encoding,
CompressionType compressor,
Map<String,String> props)
Add one timeseries to metadata tree, if the timeseries already exists, throw exception
|
void |
MManager.deactivateSchemaTemplate(DeactivateTemplatePlan plan) |
void |
MManager.deleteLastCacheByDevice(PartialPath deviceId)
delete all the last cache value of any timeseries or aligned timeseries under the device
Invoking scenario (1) after upload tsfile
|
void |
MManager.deleteLastCacheByDevice(PartialPath deviceId,
PartialPath originalPath,
long startTime,
long endTime)
delete the last cache value of timeseries or subMeasurement of some aligned timeseries, which
is under the device and matching the originalPath
Invoking scenario (1) delete timeseries
|
void |
MManager.deleteStorageGroups(List<PartialPath> storageGroups)
Delete storage groups of given paths from MTree.
|
String |
MManager.deleteTimeseries(PartialPath pathPattern)
Delete all timeseries matching the given path pattern, may cross different storage group
|
String |
MManager.deleteTimeseries(PartialPath pathPattern,
boolean isPrefixMatch)
Delete all timeseries matching the given path pattern, may cross different storage group.
|
void |
MManager.dropSchemaTemplate(DropTemplatePlan plan) |
void |
MManager.dropTagsOrAttributes(Set<String> keySet,
PartialPath fullPath)
drop tags or attributes of the timeseries
|
Map<PartialPath,IMeasurementSchema> |
MManager.getAllMeasurementSchemaByPrefix(PartialPath prefixPath) |
int |
MManager.getAllTimeseriesCount(PartialPath pathPattern)
To calculate the count of timeseries matching given path.
|
int |
MManager.getAllTimeseriesCount(PartialPath pathPattern,
boolean isPrefixMatch)
To calculate the count of timeseries matching given path.
|
Set<PartialPath> |
MManager.getBelongedDevices(PartialPath timeseries)
Get all devices that one of the timeseries, matching the given timeseries path pattern, belongs
to.
|
List<PartialPath> |
MManager.getBelongedStorageGroups(PartialPath pathPattern)
Get the storage group that given path pattern matches or belongs to.
|
Set<String> |
MManager.getChildNodeNameInNextLevel(PartialPath pathPattern)
Get child node in the next level of the given path pattern.
|
Set<String> |
MManager.getChildNodeNameInNextLevel(PartialPath pathPattern,
int limit,
int offset) |
Set<String> |
MManager.getChildNodePathInNextLevel(PartialPath pathPattern)
Get child node path in the next level of the given path pattern.
|
Set<String> |
MManager.getChildNodePathInNextLevel(PartialPath pathPattern,
int limit,
int offset) |
IMNode |
MManager.getDeviceNode(PartialPath path) |
protected IMNode |
MManager.getDeviceNodeWithAutoCreate(PartialPath path) |
protected IMNode |
MManager.getDeviceNodeWithAutoCreate(PartialPath path,
boolean autoCreateSchema,
boolean allowCreateSg,
int sgLevel)
get device node, if the storage group is not set, create it when autoCreateSchema is true
(we develop this method as we need to get the node's lock after we get the lock.writeLock())
|
int |
MManager.getDevicesNum(PartialPath pathPattern)
To calculate the count of devices for given path pattern.
|
int |
MManager.getDevicesNum(PartialPath pathPattern,
boolean isPrefixMatch)
To calculate the count of devices for given path pattern.
|
Set<PartialPath> |
MManager.getMatchedDevices(PartialPath pathPattern,
boolean isPrefixMatch)
Get all device paths matching the path pattern.
|
List<ShowDevicesResult> |
MManager.getMatchedDevices(ShowDevicesPlan plan)
Get all device paths and according storage group paths as ShowDevicesResult.
|
List<PartialPath> |
MManager.getMatchedStorageGroups(PartialPath pathPattern,
boolean isPrefixMatch)
Get all storage group matching given path pattern.
|
Map<PartialPath,Integer> |
MManager.getMeasurementCountGroupByLevel(PartialPath pathPattern,
int level,
boolean isPrefixMatch) |
IMeasurementMNode |
MManager.getMeasurementMNode(PartialPath fullPath) |
IMeasurementMNode[] |
MManager.getMeasurementMNodes(PartialPath deviceId,
String[] measurements) |
List<MeasurementPath> |
MManager.getMeasurementPaths(PartialPath pathPattern)
Return all measurement paths for given path if the path is abstract.
|
List<MeasurementPath> |
MManager.getMeasurementPaths(PartialPath pathPattern,
boolean isPrefixMatch)
Return all measurement paths for given path if the path is abstract.
|
Pair<List<MeasurementPath>,Integer> |
MManager.getMeasurementPathsWithAlias(PartialPath pathPattern,
int limit,
int offset,
boolean isPrefixMatch)
Similar to method getMeasurementPaths(), but return Path with alias and filter the result by
limit and offset.
|
List<String> |
MManager.getMeasurementsInTemplate(String templateName,
String path) |
int |
MManager.getNodesCountInGivenLevel(PartialPath pathPattern,
int level)
To calculate the count of nodes in the given level for given path pattern.
|
int |
MManager.getNodesCountInGivenLevel(PartialPath pathPattern,
int level,
boolean isPrefixMatch)
To calculate the count of nodes in the given level for given path pattern.
|
List<PartialPath> |
MManager.getNodesListInGivenLevel(PartialPath pathPattern,
int nodeLevel)
Get all nodes matching the given path pattern in the given level.
|
List<PartialPath> |
MManager.getNodesListInGivenLevel(PartialPath pathPattern,
int nodeLevel,
MManager.StorageGroupFilter filter) |
Set<String> |
MManager.getPathsSetTemplate(String templateName)
Get all paths set designated template
|
Set<String> |
MManager.getPathsUsingTemplate(String templateName)
A shortcut mainly for viewing paths using template.
|
Set<PartialPath> |
MManager.getPathsUsingTemplateUnderPrefix(String templateName,
String prefix,
boolean prefixMatch)
Complete filter of paths using template, detail at
MTree.getPathsUsingTemplateUnderPrefix(org.apache.iotdb.db.metadata.template.Template, org.apache.iotdb.db.metadata.path.PartialPath, boolean) |
List<Pair<String,IMeasurementSchema>> |
MManager.getSchemasInTemplate(String templateName,
String path) |
IMeasurementSchema |
MManager.getSeriesSchema(PartialPath fullPath)
Get schema of paritialPath
|
IMNode |
MManager.getSeriesSchemasAndReadLockDevice(InsertPlan plan)
get schema for device.
|
TSDataType |
MManager.getSeriesType(PartialPath fullPath)
Get series type for given seriesPath.
|
IStorageGroupMNode |
MManager.getStorageGroupNodeByPath(PartialPath path)
Get storage group node by path. the give path don't need to be storage group path.
|
IStorageGroupMNode |
MManager.getStorageGroupNodeByStorageGroupPath(PartialPath path)
E.g., root.sg is storage group given [root, sg], return the MNode of root.sg given [root, sg,
device], return the MNode of root.sg Get storage group node by path.
|
int |
MManager.getStorageGroupNum(PartialPath pathPattern,
boolean isPrefixMatch)
To calculate the count of storage group for given path pattern.
|
Template |
MManager.getTemplate(String templateName) |
Map<String,List<PartialPath>> |
MManager.groupPathByStorageGroup(PartialPath path)
For a path, infer all storage groups it may belong to.
|
boolean |
MManager.isMeasurementInTemplate(String templateName,
String path) |
boolean |
MManager.isPathExistsInTemplate(String templateName,
String path) |
void |
MManager.operation(PhysicalPlan plan) |
void |
MManager.pruneSchemaTemplate(PruneTemplatePlan plan) |
void |
MManager.renameTagOrAttributeKey(String oldKey,
String newKey,
PartialPath fullPath)
rename the tag or attribute's key of the timeseries
|
void |
MManager.setSchemaTemplate(SetTemplatePlan plan) |
void |
MManager.setStorageGroup(PartialPath storageGroup)
Set storage group of the given path to MTree.
|
void |
MManager.setTagsOrAttributesValue(Map<String,String> alterMap,
PartialPath fullPath)
set/change the values of tags or attributes
|
void |
MManager.setTTL(PartialPath storageGroup,
long dataTTL) |
void |
MManager.setUsingSchemaTemplate(ActivateTemplatePlan plan) |
List<ShowTimeSeriesResult> |
MManager.showTimeseries(ShowTimeSeriesPlan plan,
QueryContext context) |
void |
MManager.unsetSchemaTemplate(UnsetTemplatePlan plan) |
void |
MManager.upsertTagsAndAttributes(String alias,
Map<String,String> tagsMap,
Map<String,String> attributesMap,
PartialPath fullPath)
upsert tags and attributes key-value for the timeseries if the key has existed, just use the
new value to update it.
|
| 限定符和类型 | 方法和说明 |
|---|---|
void |
IDTableHashmapImpl.createAlignedTimeseries(CreateAlignedTimeSeriesPlan plan)
create aligned timeseries
|
void |
IDTable.createAlignedTimeseries(CreateAlignedTimeSeriesPlan plan)
create aligned timeseries
|
void |
IDTableHashmapImpl.createTimeseries(CreateTimeSeriesPlan plan)
create timeseries
|
void |
IDTable.createTimeseries(CreateTimeSeriesPlan plan)
create timeseries
|
void |
IDTableHashmapImpl.deregisterTrigger(PartialPath fullPath,
IMeasurementMNode measurementMNode)
deregister trigger to the timeseries
|
void |
IDTable.deregisterTrigger(PartialPath fullPath,
IMeasurementMNode measurementMNode)
deregister trigger to the timeseries
|
TimeValuePair |
IDTableHashmapImpl.getLastCache(TimeseriesID timeseriesID)
get last cache of the timeseies
|
TimeValuePair |
IDTable.getLastCache(TimeseriesID timeseriesID)
get last cache of the timeseies
|
IDeviceID |
IDTableHashmapImpl.getSeriesSchemas(InsertPlan plan)
check inserting timeseries existence and fill their measurement mnode
|
IDeviceID |
IDTable.getSeriesSchemas(InsertPlan plan)
check inserting timeseries existence and fill their measurement mnode
|
void |
IDTableHashmapImpl.putSchemaEntry(String devicePath,
String measurement,
SchemaEntry schemaEntry,
boolean isAligned) |
void |
IDTable.putSchemaEntry(String devicePath,
String measurement,
SchemaEntry schemaEntry,
boolean isAligned)
put schema entry to id table, currently used in recover
|
void |
IDTableHashmapImpl.registerTrigger(PartialPath fullPath,
IMeasurementMNode measurementMNode)
register trigger to the timeseries
|
void |
IDTable.registerTrigger(PartialPath fullPath,
IMeasurementMNode measurementMNode)
register trigger to the timeseries
|
void |
IDTableHashmapImpl.updateLastCache(TimeseriesID timeseriesID,
TimeValuePair pair,
boolean highPriorityUpdate,
Long latestFlushedTime)
update last cache of the timeseies
|
void |
IDTable.updateLastCache(TimeseriesID timeseriesID,
TimeValuePair pair,
boolean highPriorityUpdate,
Long latestFlushedTime)
update last cache of the timeseies
|
| 限定符和类型 | 方法和说明 |
|---|---|
void |
MLogUpgrader.operation(String cmd)
upgrade from mlog.txt to mlog.bin
|
void |
MLogUpgrader.operation(String cmd,
boolean isSnapshot) |
| 限定符和类型 | 方法和说明 |
|---|---|
IMNode |
MTree.checkTemplateAlignmentWithMountedNode(IMNode mountedNode,
Template template)
Check route 1: If template has no direct measurement, just pass the check.
|
void |
MTree.checkTemplateOnPath(PartialPath path)
check whether there is template on given path and the subTree has template return true,
otherwise false
|
void |
MTree.collectMeasurementSchema(PartialPath prefixPath,
List<IMeasurementSchema> measurementSchemas)
Collect the timeseries schemas as IMeasurementSchema under "prefixPath".
|
void |
MTree.collectTimeseriesSchema(PartialPath prefixPath,
Collection<TimeseriesSchema> timeseriesSchemas)
Collect the timeseries schemas as TimeseriesSchema under "prefixPath".
|
void |
MTree.createAlignedTimeseries(PartialPath devicePath,
List<String> measurements,
List<TSDataType> dataTypes,
List<TSEncoding> encodings,
List<CompressionType> compressors)
Create aligned timeseries with full paths from root to one leaf node.
|
IMeasurementMNode |
MTree.createTimeseries(PartialPath path,
TSDataType dataType,
TSEncoding encoding,
CompressionType compressor,
Map<String,String> props,
String alias)
Create a timeseries with a full path from root to leaf node.
|
List<IMeasurementMNode> |
MTree.deleteStorageGroup(PartialPath path)
Delete a storage group
|
Pair<PartialPath,IMeasurementMNode> |
MTree.deleteTimeseriesAndReturnEmptyStorageGroup(PartialPath path)
Delete path.
|
List<Pair<PartialPath,String[]>> |
MTree.getAllMeasurementSchema(ShowTimeSeriesPlan plan)
Get all measurement schema matching the given path pattern
result: [name, alias, storage group, dataType, encoding, compression, offset]
|
List<Pair<PartialPath,String[]>> |
MTree.getAllMeasurementSchemaByHeatOrder(ShowTimeSeriesPlan plan,
QueryContext queryContext)
Get all measurement schema matching the given path pattern order by insert frequency
result: [name, alias, storage group, dataType, encoding, compression, offset]
|
Map<PartialPath,IMeasurementSchema> |
MTree.getAllMeasurementSchemaByPrefix(PartialPath prefixPath) |
int |
MTree.getAllTimeseriesCount(PartialPath pathPattern)
Get the count of timeseries matching the given path.
|
int |
MTree.getAllTimeseriesCount(PartialPath pathPattern,
boolean isPrefixMatch,
boolean traverseTemplate)
Get the count of timeseries matching the given path.
|
List<PartialPath> |
MTree.getBelongedStorageGroups(PartialPath pathPattern)
Get the storage group that given path pattern matches or belongs to.
|
Set<String> |
MTree.getChildNodeNameInNextLevel(PartialPath pathPattern,
int limit,
int offset)
Get child node in the next level of the given path.
|
Set<String> |
MTree.getChildNodePathInNextLevel(PartialPath pathPattern,
int limit,
int offset)
Get child node path in the next level of the given path pattern.
|
IMNode |
MTree.getDeviceNodeWithAutoCreating(PartialPath deviceId,
int sgLevel)
Add an interval path to MTree.
|
Set<PartialPath> |
MTree.getDevices(PartialPath pathPattern,
boolean isPrefixMatch)
Get all devices matching the given path pattern.
|
List<ShowDevicesResult> |
MTree.getDevices(ShowDevicesPlan plan) |
Set<PartialPath> |
MTree.getDevicesByTimeseries(PartialPath timeseries) |
int |
MTree.getDevicesNum(PartialPath pathPattern)
Get the count of devices matching the given path.
|
int |
MTree.getDevicesNum(PartialPath pathPattern,
boolean isPrefixMatch)
Get the count of devices matching the given path.
|
List<PartialPath> |
MTree.getMatchedStorageGroups(PartialPath pathPattern,
boolean isPrefixMatch)
Get all storage group that the given path pattern matches.
|
Map<PartialPath,Integer> |
MTree.getMeasurementCountGroupByLevel(PartialPath pathPattern,
int level) |
Map<PartialPath,Integer> |
MTree.getMeasurementCountGroupByLevel(PartialPath pathPattern,
int level,
boolean isPrefixMatch) |
IMeasurementMNode |
MTree.getMeasurementMNode(PartialPath path) |
List<MeasurementPath> |
MTree.getMeasurementPaths(PartialPath pathPattern)
Get all measurement paths matching the given path pattern
|
List<MeasurementPath> |
MTree.getMeasurementPaths(PartialPath pathPattern,
boolean isPrefixMatch)
Get all measurement paths matching the given path pattern.
|
Pair<List<MeasurementPath>,Integer> |
MTree.getMeasurementPathsWithAlias(PartialPath pathPattern,
int limit,
int offset)
Get all measurement paths matching the given path pattern
|
Pair<List<MeasurementPath>,Integer> |
MTree.getMeasurementPathsWithAlias(PartialPath pathPattern,
int limit,
int offset,
boolean isPrefixMatch)
Get all measurement paths matching the given path pattern If using prefix match, the path
pattern is used to match prefix path.
|
int |
MTree.getMountedNodeIndexOnMeasurementPath(PartialPath measurementPath)
Check measurement path and return the mounted node index on path.
|
IMNode |
MTree.getNodeByPath(PartialPath path)
Get node by the path
|
IMNode |
MTree.getNodeByPathWithStorageGroupCheck(PartialPath path)
Get node by path with storage group check If storage group is not set,
StorageGroupNotSetException will be thrown
|
int |
MTree.getNodesCountInGivenLevel(PartialPath pathPattern,
int level)
Get the count of nodes in the given level matching the given path.
|
int |
MTree.getNodesCountInGivenLevel(PartialPath pathPattern,
int level,
boolean isPrefixMatch)
Get the count of nodes in the given level matching the given path.
|
List<PartialPath> |
MTree.getNodesListInGivenLevel(PartialPath pathPattern,
int nodeLevel,
MManager.StorageGroupFilter filter)
Get all paths from root to the given level
|
List<String> |
MTree.getPathsSetOnTemplate(Template template) |
List<PartialPath> |
MTree.getPathsUsingTemplateUnderPrefix(Template template,
PartialPath prefix,
boolean prefixMode)
Notice that wildcards do not semantically equal prefix match.
|
IStorageGroupMNode |
MTree.getStorageGroupNodeByPath(PartialPath path)
E.g., root.sg is storage group given [root, sg], return the MNode of root.sg given [root, sg,
device], return the MNode of root.sg Get storage group node, the give path don't need to be
storage group path.
|
IStorageGroupMNode |
MTree.getStorageGroupNodeByStorageGroupPath(PartialPath path)
E.g., root.sg is storage group given [root, sg], return the MNode of root.sg given [root, sg,
device], throw exception Get storage group node, if the give path is not a storage group, throw
exception
|
int |
MTree.getStorageGroupNum(PartialPath pathPattern)
Get the count of storage group matching the given path.
|
int |
MTree.getStorageGroupNum(PartialPath pathPattern,
boolean isPrefixMatch)
Get the count of storage group matching the given path.
|
Map<String,List<PartialPath>> |
MTree.groupPathByStorageGroup(PartialPath path)
Resolve the path or path pattern into StorageGroupName-FullPath pairs.
|
boolean |
MTree.isTemplateAppendable(Template tarTemplate,
List<String> appendMeasurements)
Check that each node set with tarTemplate and its descendants have overlapping nodes with
appending measurements
|
void |
MTree.processMNodeDuringTraversal(PartialPath pathPattern,
BiConsumer<IMNode,Long> consumer) |
void |
MTree.setStorageGroup(PartialPath path)
Set storage group.
|
| 限定符和类型 | 方法和说明 |
|---|---|
protected abstract boolean |
Traverser.processFullMatchedMNode(IMNode node,
int idx,
int level)
full match: root.sg.d full match root.sg.
|
protected abstract boolean |
Traverser.processInternalMatchedMNode(IMNode node,
int idx,
int level)
internal match: root.sg internal match root.sg.
|
protected void |
Traverser.processMultiLevelWildcard(IMNode node,
int idx,
int level) |
protected void |
Traverser.processNameMatch(IMNode node,
int idx,
int level) |
protected void |
Traverser.processOneLevelWildcard(IMNode node,
int idx,
int level) |
void |
Traverser.traverse()
The interface to start the traversal.
|
protected void |
Traverser.traverse(IMNode node,
int idx,
int level)
The recursive method for MTree traversal.
|
| 构造器和说明 |
|---|
Traverser(IMNode startNode,
PartialPath path)
To traverse subtree under root.sg, e.g., init Traverser(root, "root.sg.**")
|
| 限定符和类型 | 方法和说明 |
|---|---|
protected abstract void |
EntityCollector.collectEntity(IEntityMNode node) |
protected abstract void |
MeasurementCollector.collectMeasurement(IMeasurementMNode node)
collect the information of one measurement
|
protected MeasurementPath |
MeasurementCollector.getCurrentMeasurementPathInTraverse(IMeasurementMNode currentNode)
When traverse goes into a template, IMNode.getPartialPath may not work as nodes in template has
no parent on MTree.
|
protected boolean |
MeasurementCollector.processFullMatchedMNode(IMNode node,
int idx,
int level) |
protected boolean |
EntityCollector.processFullMatchedMNode(IMNode node,
int idx,
int level) |
protected boolean |
MeasurementCollector.processInternalMatchedMNode(IMNode node,
int idx,
int level) |
protected void |
MNodeCollector.traverse(IMNode node,
int idx,
int level) |
protected void |
CollectorTraverser.traverse(IMNode node,
int idx,
int level)
extends traversal with limit restriction
|
| 构造器和说明 |
|---|
CollectorTraverser(IMNode startNode,
PartialPath path) |
CollectorTraverser(IMNode startNode,
PartialPath path,
int limit,
int offset) |
EntityCollector(IMNode startNode,
PartialPath path) |
EntityCollector(IMNode startNode,
PartialPath path,
int limit,
int offset) |
MeasurementCollector(IMNode startNode,
PartialPath path) |
MeasurementCollector(IMNode startNode,
PartialPath path,
int limit,
int offset) |
MNodeCollector(IMNode startNode,
PartialPath path) |
StorageGroupCollector(IMNode startNode,
PartialPath path) |
| 限定符和类型 | 方法和说明 |
|---|---|
protected boolean |
MeasurementGroupByLevelCounter.processFullMatchedMNode(IMNode node,
int idx,
int level) |
protected boolean |
MeasurementGroupByLevelCounter.processInternalMatchedMNode(IMNode node,
int idx,
int level) |
| 构造器和说明 |
|---|
CounterTraverser(IMNode startNode,
PartialPath path) |
EntityCounter(IMNode startNode,
PartialPath path) |
MeasurementCounter(IMNode startNode,
PartialPath path) |
MeasurementGroupByLevelCounter(IMNode startNode,
PartialPath path,
int groupByLevel) |
MNodeLevelCounter(IMNode startNode,
PartialPath path,
int targetLevel) |
StorageGroupCounter(IMNode startNode,
PartialPath path) |
| 限定符和类型 | 方法和说明 |
|---|---|
IMeasurementSchema |
PartialPath.getMeasurementSchema() |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
TagManager.addAttributes(Map<String,String> attributesMap,
PartialPath fullPath,
IMeasurementMNode leafMNode)
add new attributes key-value for the timeseries
|
void |
TagManager.addTags(Map<String,String> tagsMap,
PartialPath fullPath,
IMeasurementMNode leafMNode)
add new tags key-value for the timeseries
|
void |
TagManager.dropTagsOrAttributes(Set<String> keySet,
PartialPath fullPath,
IMeasurementMNode leafMNode)
drop tags or attributes of the timeseries
|
List<IMeasurementMNode> |
TagManager.getMatchedTimeseriesInIndex(ShowTimeSeriesPlan plan,
QueryContext context) |
void |
TagManager.renameTagOrAttributeKey(String oldKey,
String newKey,
PartialPath fullPath,
IMeasurementMNode leafMNode)
rename the tag or attribute's key of the timeseries
|
void |
TagManager.setTagsOrAttributesValue(Map<String,String> alterMap,
PartialPath fullPath,
IMeasurementMNode leafMNode)
set/change the values of tags or attributes
|
void |
TagManager.updateTagsAndAttributes(Map<String,String> tagsMap,
Map<String,String> attributesMap,
IMeasurementMNode leafMNode)
upsert tags and attributes key-value for the timeseries if the key has existed, just use the
new value to update it.
|
long |
TagLogFile.write(Map<String,String> tagMap,
Map<String,String> attributeMap) |
void |
TagLogFile.write(Map<String,String> tagMap,
Map<String,String> attributeMap,
long position)
This method does not modify this file's current position.
|
long |
TagManager.writeTagFile(Map<String,String> tags,
Map<String,String> attributes) |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
TemplateManager.appendSchemaTemplate(AppendTemplatePlan plan) |
void |
TemplateManager.checkTemplateCompatible(Template template,
IMNode node) |
void |
TemplateManager.createSchemaTemplate(CreateTemplatePlan plan) |
void |
Template.deleteMeasurements(String path) |
void |
Template.deleteSeriesCascade(String path) |
List<String> |
Template.getMeasurementsUnderPath(String path) |
boolean |
Template.isPathMeasurement(String path) |
void |
TemplateManager.pruneSchemaTemplate(PruneTemplatePlan plan) |
| 限定符和类型 | 方法和说明 |
|---|---|
static void |
MetaFormatUtils.checkNodeName(String name)
check whether the node name is well formatted
|
static void |
MetaFormatUtils.checkSchemaMeasurementNames(List<String> measurements)
check whether the measurement ids in schema is well formatted
|
static PartialPath |
MetaUtils.getStorageGroupPathByLevel(PartialPath path,
int level)
Get storage group path when creating schema automatically is enable
e.g., path = root.a.b.c and level = 1, return root.a
|
| 限定符和类型 | 方法和说明 |
|---|---|
protected int |
PlanExecutor.getDevicesNum(PartialPath path,
boolean isPrefixMatch) |
protected Set<String> |
PlanExecutor.getNodeNextChildren(PartialPath path,
int limit,
int offset) |
protected List<PartialPath> |
PlanExecutor.getNodesList(PartialPath schemaPattern,
int level) |
protected int |
PlanExecutor.getNodesNumInGivenLevel(PartialPath path,
int level,
boolean isPrefixMatch) |
protected Set<String> |
PlanExecutor.getPathNextChildren(PartialPath path,
int limit,
int offset) |
protected List<MeasurementPath> |
PlanExecutor.getPathsName(PartialPath path) |
protected int |
PlanExecutor.getPathsNum(PartialPath path,
boolean isPrefixMatch) |
protected List<PartialPath> |
PlanExecutor.getStorageGroupNames(PartialPath path,
boolean isPrefixMatch) |
QueryDataSet |
PlanExecutor.processQuery(PhysicalPlan queryPlan,
QueryContext context) |
QueryDataSet |
IPlanExecutor.processQuery(PhysicalPlan queryPlan,
QueryContext context)
process query plan of qp layer, construct queryDataSet.
|
protected QueryDataSet |
PlanExecutor.processShowQuery(ShowPlan showPlan,
QueryContext context) |
| 限定符和类型 | 方法和说明 |
|---|---|
protected Set<PartialPath> |
QueryOperator.getMatchedDevices(PartialPath path) |
protected List<MeasurementPath> |
QueryOperator.getMatchedTimeseries(PartialPath path) |
protected Pair<IUnaryExpression,String> |
InOperator.transformToSingleQueryFilter(Map<PartialPath,TSDataType> pathTSDataTypeHashMap) |
protected Pair<IUnaryExpression,String> |
LikeOperator.transformToSingleQueryFilter(Map<PartialPath,TSDataType> pathTSDataTypeHashMap) |
protected Pair<IUnaryExpression,String> |
BasicFunctionOperator.transformToSingleQueryFilter(Map<PartialPath,TSDataType> pathTSDataTypeHashMap) |
protected Pair<IUnaryExpression,String> |
FilterOperator.transformToSingleQueryFilter(Map<PartialPath,TSDataType> pathTSDataTypeHashMap)
it will be used in BasicFunction Operator.
|
protected Pair<IUnaryExpression,String> |
RegexpOperator.transformToSingleQueryFilter(Map<PartialPath,TSDataType> pathTSDataTypeHashMap) |
| 限定符和类型 | 方法和说明 |
|---|---|
abstract void |
QueryPlan.deduplicate(PhysicalGenerator physicalGenerator) |
void |
RawDataQueryPlan.deduplicate(PhysicalGenerator physicalGenerator) |
void |
LastQueryPlan.deduplicate(PhysicalGenerator physicalGenerator) |
void |
UDTFPlan.deduplicate(PhysicalGenerator physicalGenerator) |
void |
UDAFPlan.deduplicate(PhysicalGenerator physicalGenerator) |
org.apache.iotdb.service.rpc.thrift.TSExecuteStatementResp |
QueryPlan.getTSExecuteStatementResp(boolean isJdbcQuery)
Construct the header of result set.
|
org.apache.iotdb.service.rpc.thrift.TSExecuteStatementResp |
GroupByTimePlan.getTSExecuteStatementResp(boolean isJdbcQuery) |
org.apache.iotdb.service.rpc.thrift.TSExecuteStatementResp |
AggregationPlan.getTSExecuteStatementResp(boolean isJdbcQuery) |
org.apache.iotdb.service.rpc.thrift.TSExecuteStatementResp |
UDAFPlan.getTSExecuteStatementResp(boolean isJdbcQuery) |
List<TSDataType> |
QueryPlan.getWideQueryHeaders(List<String> respColumns,
List<String> respSgColumns,
boolean isJdbcQuery,
BitSet aliasList) |
List<TSDataType> |
AggregationPlan.getWideQueryHeaders(List<String> respColumns,
List<String> respSgColumns,
boolean isJdbcQuery,
BitSet aliasList) |
void |
RawDataQueryPlan.groupVectorPaths(PhysicalGenerator physicalGenerator)
Group all the subSensors of one vector into one VectorPartialPath save the grouped
VectorPartialPath in deduplicatedVectorPaths instead of putting them directly into
deduplicatedPaths, because we don't know whether the raw query has value filter here.
|
| 限定符和类型 | 方法和说明 |
|---|---|
static CreateTemplatePlan |
CreateTemplatePlan.deserializeFromReq(ByteBuffer buffer) |
| 限定符和类型 | 方法和说明 |
|---|---|
List<PartialPath> |
PhysicalGenerator.groupVectorPaths(List<PartialPath> paths) |
| 限定符和类型 | 方法和说明 |
|---|---|
List<RowRecord> |
ShowTimeseriesDataSet.getQueryDataSet() |
abstract List<RowRecord> |
ShowDataSet.getQueryDataSet() |
List<RowRecord> |
ShowDevicesDataSet.getQueryDataSet() |
| 构造器和说明 |
|---|
ShowDevicesDataSet(ShowDevicesPlan showDevicesPlan) |
ShowTimeseriesDataSet(ShowTimeSeriesPlan showTimeSeriesPlan,
QueryContext context) |
| 限定符和类型 | 方法和说明 |
|---|---|
TSDataType |
UDFParameters.getDataType(int index) |
List<TSDataType> |
UDFParameters.getDataTypes() |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
UDTFDerivative.beforeStart(UDFParameters parameters,
UDTFConfigurations configurations) |
void |
UDTFContinuouslySatisfy.beforeStart(UDFParameters parameters,
UDTFConfigurations configurations) |
void |
UDTFInRange.beforeStart(UDFParameters parameters,
UDTFConfigurations configurations) |
void |
UDTFSelectK.beforeStart(UDFParameters parameters,
UDTFConfigurations configurations) |
void |
UDTFAbs.beforeStart(UDFParameters parameters,
UDTFConfigurations configurations) |
void |
UDTFOnOff.beforeStart(UDFParameters parameters,
UDTFConfigurations configurations) |
void |
UDTFValueDifference.beforeStart(UDFParameters parameters,
UDTFConfigurations configurations) |
void |
UDTFCast.beforeStart(UDFParameters parameters,
UDTFConfigurations configurations) |
void |
UDTFMath.beforeStart(UDFParameters parameters,
UDTFConfigurations configurations) |
| 限定符和类型 | 方法和说明 |
|---|---|
QueryDataSet |
ServiceProvider.createQueryDataSet(QueryContext context,
PhysicalPlan physicalPlan,
int fetchSize)
create QueryDataSet and buffer it for fetchResults
|
| 限定符和类型 | 方法和说明 |
|---|---|
static void |
DeviceMappingViewer.main(String[] args) |
| 限定符和类型 | 方法和说明 |
|---|---|
static void |
SchemaUtils.checkDataTypeWithEncoding(TSDataType dataType,
TSEncoding encoding) |
Copyright © 2022 The Apache Software Foundation. All rights reserved.