| 类和说明 |
|---|
| IllegalPathException |
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| StorageGroupNotSetException |
| 类和说明 |
|---|
| IllegalPathException |
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| IllegalPathException |
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| IllegalPathException |
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| IllegalPathException |
| 类和说明 |
|---|
| IllegalPathException |
| StorageGroupNotSetException |
| 类和说明 |
|---|
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| PathAlreadyExistException |
| PathNotExistException |
| StorageGroupNotSetException |
| 类和说明 |
|---|
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| IllegalPathException |
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| StorageGroupNotSetException |
| TemplateIsInUseException |
| 类和说明 |
|---|
| IllegalPathException |
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| IllegalPathException |
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| IllegalPathException |
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| UndefinedTemplateException |
| 类和说明 |
|---|
| IllegalParameterOfPathException |
| IllegalPathException |
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| IllegalPathException |
| 类和说明 |
|---|
| IllegalPathException |
| 类和说明 |
|---|
| IllegalPathException |
| 类和说明 |
|---|
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| StorageGroupNotSetException |
| 类和说明 |
|---|
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| IllegalPathException |
| 类和说明 |
|---|
| IllegalPathException |
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| IllegalPathException |
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| IllegalPathException |
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| StorageGroupNotSetException |
| 类和说明 |
|---|
| IllegalPathException |
| 类和说明 |
|---|
| IllegalPathException |
| 类和说明 |
|---|
| IllegalPathException |
| 类和说明 |
|---|
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
| 类和说明 |
|---|
| MetadataException
If query metadata constructs schema but passes illegal parameters to EncodingConvertor or
DataTypeConverter,this exception will be threw.
|
Copyright © 2022 The Apache Software Foundation. All rights reserved.