| 限定符和类型 | 方法和说明 |
|---|---|
void |
IoTDBDescriptor.loadHotModifiedProps() |
void |
IoTDBDescriptor.loadHotModifiedProps(Properties properties) |
| 限定符和类型 | 方法和说明 |
|---|---|
protected void |
ContinuousQueryTask.doInsert(String sql,
QueryOperator queryOperator,
GroupByTimePlan queryPlan,
QueryDataSet queryDataSet) |
void |
ContinuousQueryTask.runMayThrow() |
| 限定符和类型 | 方法和说明 |
|---|---|
ReadOnlyMemChunk |
AbstractMemTable.query(PartialPath fullPath,
long ttlLowerBound,
List<Pair<Modification,IMemTable>> modsToMemtable) |
ReadOnlyMemChunk |
IMemTable.query(PartialPath fullPath,
long ttlLowerBound,
List<Pair<Modification,IMemTable>> modsToMemtable) |
| 构造器和说明 |
|---|
AlignedReadOnlyMemChunk(IMeasurementSchema schema,
TVList tvList,
int size,
List<List<TimeRange>> deletionList)
The constructor for Aligned type.
|
ReadOnlyMemChunk(String measurementUid,
TSDataType dataType,
TSEncoding encoding,
TVList tvList,
Map<String,String> props,
int size,
List<TimeRange> deletionList) |
| 限定符和类型 | 方法和说明 |
|---|---|
QueryDataSource |
VirtualStorageGroupProcessor.query(List<PartialPath> pathList,
String singleDeviceId,
QueryContext context,
QueryFileManager filePathsManager,
Filter timeFilter)
build query data source by searching all tsfile which fit in query filter
|
| 限定符和类型 | 方法和说明 |
|---|---|
void |
LocalIoTDBHandler.onEvent(LocalIoTDBEvent event) |
| 限定符和类型 | 类和说明 |
|---|---|
class |
BatchProcessException |
class |
UDFRegistrationException |
| 限定符和类型 | 类和说明 |
|---|---|
class |
IndexManagerException |
class |
QueryIndexException |
class |
UnsupportedIndexTypeException |
| 限定符和类型 | 类和说明 |
|---|---|
class |
LogicalOperatorException
This exception is thrown while meeting error in transforming logical operator to physical plan.
|
class |
LogicalOptimizeException
This exception is thrown while meeting error in optimizing logical operator.
|
class |
PathException |
class |
PathNumOverLimitException |
class |
UnSupportedFillTypeException |
| 限定符和类型 | 方法和说明 |
|---|---|
ReadOnlyMemChunk |
AlignedPath.getReadOnlyMemChunkFromMemTable(IMemTable memTable,
List<Pair<Modification,IMemTable>> modsToMemtable,
long timeLowerBound) |
ReadOnlyMemChunk |
PartialPath.getReadOnlyMemChunkFromMemTable(IMemTable memTable,
List<Pair<Modification,IMemTable>> modsToMemtable,
long timeLowerBound)
get the ReadOnlyMemChunk from the given MemTable.
|
ReadOnlyMemChunk |
MeasurementPath.getReadOnlyMemChunkFromMemTable(IMemTable memTable,
List<Pair<Modification,IMemTable>> modsToMemtable,
long timeLowerBound) |
| 限定符和类型 | 方法和说明 |
|---|---|
InsertRowPlan |
IoTDBPoint.convertToInsertRowPlan() |
| 构造器和说明 |
|---|
AuthorizationHandler(ServiceProvider serviceProvider) |
| 构造器和说明 |
|---|
GrafanaApiServiceImpl() |
RestApiServiceImpl() |
| 限定符和类型 | 方法和说明 |
|---|---|
protected PhysicalPlan |
Planner.generatePhysicalPlanFromOperator(Operator operator) |
PhysicalPlan |
Planner.lastDataQueryReqToPhysicalPlan(org.apache.iotdb.service.rpc.thrift.TSLastDataQueryReq lastDataQueryReq,
ZoneId zoneId,
IoTDBConstant.ClientVersion clientVersion)
convert last data query to physical plan directly
|
PhysicalPlan |
Planner.operatorToPhysicalPlan(Operator operator) |
PhysicalPlan |
Planner.parseSQLToGrafanaQueryPlan(String sqlStr,
ZoneId zoneId) |
PhysicalPlan |
Planner.parseSQLToPhysicalPlan(String sqlStr) |
PhysicalPlan |
Planner.parseSQLToPhysicalPlan(String sqlStr,
ZoneId zoneId,
IoTDBConstant.ClientVersion clientVersion) |
PhysicalPlan |
Planner.parseSQLToRestQueryPlan(String sqlStr,
ZoneId zoneId) |
PhysicalPlan |
Planner.rawDataQueryReqToPhysicalPlan(org.apache.iotdb.service.rpc.thrift.TSRawDataQueryReq rawDataQueryReq,
ZoneId zoneId,
IoTDBConstant.ClientVersion clientVersion)
convert raw data query to physical plan directly
|
| 限定符和类型 | 方法和说明 |
|---|---|
void |
PlanExecutor.delete(DeletePlan deletePlan) |
void |
IPlanExecutor.delete(DeletePlan deletePlan)
execute delete command and return whether the operator is successful.
|
void |
PlanExecutor.delete(PartialPath path,
long startTime,
long endTime,
long planIndex,
VirtualStorageGroupProcessor.TimePartitionFilter timePartitionFilter) |
void |
IPlanExecutor.delete(PartialPath path,
long startTime,
long endTime,
long planIndex,
VirtualStorageGroupProcessor.TimePartitionFilter partitionFilter)
execute delete command and return whether the operator is successful.
|
protected boolean |
PlanExecutor.deleteStorageGroups(DeleteStorageGroupPlan deleteStorageGroupPlan) |
protected boolean |
PlanExecutor.deleteTimeSeries(DeleteTimeSeriesPlan deleteTimeSeriesPlan) |
protected AlignByDeviceDataSet |
PlanExecutor.getAlignByDeviceDataSet(AlignByDevicePlan plan,
QueryContext context,
IQueryRouter router) |
void |
PlanExecutor.insert(InsertRowPlan insertRowPlan) |
void |
IPlanExecutor.insert(InsertRowPlan insertRowPlan)
execute insert command and return whether the operator is successful.
|
void |
PlanExecutor.insert(InsertRowsOfOneDevicePlan insertRowsOfOneDevicePlan) |
void |
IPlanExecutor.insert(InsertRowsOfOneDevicePlan insertRowsOfOneDevicePlan)
execute insert command and return whether the operator is successful.
|
void |
PlanExecutor.insert(InsertRowsPlan plan) |
void |
IPlanExecutor.insert(InsertRowsPlan insertRowsPlan)
execute insert command and return whether the operator is successful.
|
void |
PlanExecutor.insertTablet(InsertMultiTabletPlan insertMultiTabletPlan) |
void |
IPlanExecutor.insertTablet(InsertMultiTabletPlan insertMultiTabletPlan)
execute multi batch insert plan
|
void |
PlanExecutor.insertTablet(InsertTabletPlan insertTabletPlan) |
void |
IPlanExecutor.insertTablet(InsertTabletPlan insertTabletPlan)
execute batch insert plan
|
protected void |
PlanExecutor.loadConfiguration(LoadConfigurationPlan plan) |
protected QueryDataSet |
PlanExecutor.processAuthorQuery(AuthorPlan plan) |
protected QueryDataSet |
PlanExecutor.processDataQuery(QueryPlan queryPlan,
QueryContext context) |
boolean |
PlanExecutor.processNonQuery(PhysicalPlan plan) |
boolean |
IPlanExecutor.processNonQuery(PhysicalPlan plan)
Process Non-Query Physical plan, including insert/update/delete operation of
data/metadata/Privilege
|
QueryDataSet |
PlanExecutor.processQuery(PhysicalPlan queryPlan,
QueryContext context) |
QueryDataSet |
IPlanExecutor.processQuery(PhysicalPlan queryPlan,
QueryContext context)
process query plan of qp layer, construct queryDataSet.
|
protected QueryDataSet |
PlanExecutor.processShowQuery(ShowPlan showPlan,
QueryContext context) |
boolean |
PlanExecutor.setStorageGroup(SetStorageGroupPlan setStorageGroupPlan) |
void |
IPlanExecutor.update(PartialPath path,
long startTime,
long endTime,
String value)
execute update command and return whether the operator is successful.
|
| 构造器和说明 |
|---|
PlanExecutor() |
| 限定符和类型 | 方法和说明 |
|---|---|
PhysicalPlan |
Operator.generatePhysicalPlan(PhysicalGenerator generator) |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
PhysicalPlan.checkIntegrity()
Check the integrity of the plan in case that the plan is generated by a careless user through
Session API.
|
| 限定符和类型 | 方法和说明 |
|---|---|
void |
AlignByDevicePlan.calcWithoutNullColumnIndex(List<Expression> withoutNullColumns) |
void |
InsertRowPlan.checkIntegrity() |
void |
InsertTabletPlan.checkIntegrity() |
void |
InsertRowsPlan.checkIntegrity() |
void |
InsertMultiTabletPlan.checkIntegrity() |
void |
InsertPlan.checkIntegrity() |
abstract void |
QueryPlan.convertSpecialClauseValues(SpecialClauseComponent specialClauseComponent) |
void |
RawDataQueryPlan.convertSpecialClauseValues(SpecialClauseComponent specialClauseComponent) |
void |
AlignByDevicePlan.convertSpecialClauseValues(SpecialClauseComponent specialClauseComponent) |
void |
InsertRowPlan.fillValues(ByteBuffer buffer)
Make sure the values is already inited before calling this
|
static GlobalTimeExpression |
GroupByTimePlan.getTimeExpression(GroupByTimePlan plan) |
void |
RawDataQueryPlan.setExpression(IExpression expression) |
void |
LastQueryPlan.setExpression(IExpression expression) |
void |
InsertRowPlan.transferType()
if inferType is true, transfer String[] values to specific data types (Integer, Long, Float,
Double, Binary)
|
| 构造器和说明 |
|---|
InsertRowPlan(PartialPath prefixPath,
long insertTime,
String[] measurementList,
ByteBuffer values,
boolean isAligned) |
InsertRowsOfOneDevicePlan(PartialPath prefixPath,
List<Long> insertTimes,
List<List<String>> measurements,
List<ByteBuffer> insertValues,
boolean isAligned) |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
CreateMultiTimeSeriesPlan.checkIntegrity() |
| 构造器和说明 |
|---|
LoadConfigurationPlan(LoadConfigurationPlan.LoadConfigurationPlanType loadConfigurationPlanType) |
LoadConfigurationPlan(LoadConfigurationPlan.LoadConfigurationPlanType loadConfigurationPlanType,
Properties[] propertiesArray) |
| 限定符和类型 | 方法和说明 |
|---|---|
PhysicalPlan |
PhysicalGenerator.generateLoadConfigurationPlan(LoadConfigurationOperator.LoadConfigurationOperatorType type) |
PhysicalPlan |
PhysicalGenerator.transformToPhysicalPlan(Operator operator) |
| 限定符和类型 | 方法和说明 |
|---|---|
FilterOperator |
IFilterOptimizer.optimize(FilterOperator filter) |
| 限定符和类型 | 方法和说明 |
|---|---|
abstract void |
AggregateResult.updateResultFromPageData(IBatchDataIterator batchIterator)
Aggregate results cannot be calculated using Statistics directly, using the data in each page.
|
abstract void |
AggregateResult.updateResultFromStatistics(Statistics statistics)
Calculate the aggregation using Statistics
|
| 限定符和类型 | 方法和说明 |
|---|---|
QueryDataSource |
QueryResourceManager.getQueryDataSource(PartialPath selectedPath,
QueryContext context,
Filter timeFilter,
boolean ascending) |
void |
QueryResourceManager.initQueryDataSourceCache(Map<VirtualStorageGroupProcessor,List<PartialPath>> processorToSeriesMap,
QueryContext context,
Filter timeFilter)
The method is called in mergeLock() when executing query.
|
| 限定符和类型 | 方法和说明 |
|---|---|
org.apache.iotdb.service.rpc.thrift.TSQueryDataSet |
DirectAlignByTimeDataSet.fillBuffer(int fetchSize,
WatermarkEncoder encoder) |
org.apache.iotdb.service.rpc.thrift.TSQueryNonAlignDataSet |
UDTFNonAlignDataSet.fillBuffer(int fetchSize,
WatermarkEncoder encoder) |
org.apache.iotdb.service.rpc.thrift.TSQueryDataSet |
UDTFAlignByTimeDataSet.fillBuffer(int fetchSize,
WatermarkEncoder encoder) |
org.apache.iotdb.service.rpc.thrift.TSQueryNonAlignDataSet |
DirectNonAlignDataSet.fillBuffer(int fetchSize,
WatermarkEncoder encoder) |
protected Pair<ByteBuffer,ByteBuffer> |
UDTFNonAlignDataSet.fillColumnBuffer(int transformedDataColumnIndex,
int fetchSize,
WatermarkEncoder encoder) |
protected void |
UDTFAlignByTimeDataSet.initTimeHeap() |
protected void |
UDTFDataSet.initTransformers() |
| 构造器和说明 |
|---|
AlignByDeviceDataSet(AlignByDevicePlan alignByDevicePlan,
QueryContext context,
IQueryRouter queryRouter) |
UDTFAlignByTimeDataSet(QueryContext context,
UDTFPlan udtfPlan,
IUDFInputDataSet inputDataSet,
boolean keepNull) |
UDTFAlignByTimeDataSet(QueryContext context,
UDTFPlan udtfPlan,
List<ManagedSeriesReader> readersOfSelectedSeries)
execute without value filter
|
UDTFAlignByTimeDataSet(QueryContext context,
UDTFPlan udtfPlan,
TimeGenerator timestampGenerator,
List<IReaderByTimestamp> readersOfSelectedSeries,
List<List<Integer>> readerToIndexList,
List<Boolean> cached)
execute with value filter
|
UDTFDataSet(QueryContext queryContext,
UDTFPlan udtfPlan,
IUDFInputDataSet dataSet) |
UDTFDataSet(QueryContext queryContext,
UDTFPlan udtfPlan,
List<PartialPath> deduplicatedPaths,
List<TSDataType> deduplicatedDataTypes,
List<ManagedSeriesReader> readersOfSelectedSeries)
execute without value filters
|
UDTFDataSet(QueryContext queryContext,
UDTFPlan udtfPlan,
List<PartialPath> deduplicatedPaths,
List<TSDataType> deduplicatedDataTypes,
TimeGenerator timestampGenerator,
List<IReaderByTimestamp> readersOfSelectedSeries,
List<List<Integer>> readerToIndexList,
List<Boolean> cached)
execute with value filters
|
UDTFNonAlignDataSet(QueryContext context,
UDTFPlan udtfPlan,
List<ManagedSeriesReader> readersOfSelectedSeries)
execute without value filter
|
UDTFNonAlignDataSet(QueryContext context,
UDTFPlan udtfPlan,
TimeGenerator timestampGenerator,
List<IReaderByTimestamp> readersOfSelectedSeries,
List<List<Integer>> readerToIndexList,
List<Boolean> cached)
execute with value filter
|
| 限定符和类型 | 方法和说明 |
|---|---|
List<List<AggregateResult>> |
AlignedGroupByExecutor.calcAlignedResult(long curStartTime,
long curEndTime)
calculate result in [curStartTime, curEndTime)
|
List<List<AggregateResult>> |
LocalAlignedGroupByExecutor.calcAlignedResult(long curStartTime,
long curEndTime) |
List<AggregateResult> |
LocalGroupByExecutor.calcResult(long curStartTime,
long curEndTime) |
List<AggregateResult> |
GroupByExecutor.calcResult(long curStartTime,
long curEndTime)
calculate result in [curStartTime, curEndTime)
|
protected AlignedGroupByExecutor |
GroupByWithoutValueFilterDataSet.getAlignedGroupByExecutor(PartialPath path,
QueryContext context,
Filter timeFilter,
TsFileFilter fileFilter,
boolean ascending) |
protected GroupByExecutor |
GroupByWithoutValueFilterDataSet.getGroupByExecutor(PartialPath path,
Set<String> allSensors,
QueryContext context,
Filter timeFilter,
TsFileFilter fileFilter,
boolean ascending) |
protected IReaderByTimestamp |
GroupByWithValueFilterDataSet.getReaderByTime(PartialPath path,
RawDataQueryPlan queryPlan,
QueryContext context) |
void |
GroupByFillDataSet.initCache() |
void |
GroupByWithoutValueFilterDataSet.initGroupBy(QueryContext context,
GroupByTimePlan groupByTimePlan)
init reader and aggregate function.
|
void |
GroupByWithValueFilterDataSet.initGroupBy(QueryContext context,
GroupByTimePlan groupByTimePlan)
init reader and aggregate function.
|
| 构造器和说明 |
|---|
GroupByFillDataSet(QueryContext context,
GroupByTimeFillPlan groupByTimeFillPlan) |
LocalAlignedGroupByExecutor(PartialPath path,
QueryContext context,
Filter timeFilter,
TsFileFilter fileFilter,
boolean ascending) |
LocalGroupByExecutor(PartialPath path,
Set<String> allSensors,
QueryContext context,
Filter timeFilter,
TsFileFilter fileFilter,
boolean ascending) |
| 限定符和类型 | 方法和说明 |
|---|---|
QueryDataSet |
IQueryRouter.aggregate(AggregationPlan aggregationPlan,
QueryContext context)
Execute aggregation query.
|
QueryDataSet |
QueryRouter.aggregate(AggregationPlan aggregationPlan,
QueryContext context) |
protected void |
AggregationExecutor.aggregateOneAlignedSeries(AlignedPath alignedPath,
List<List<Integer>> subIndexes,
Set<String> allMeasurementsInDevice,
Filter timeFilter) |
static void |
AggregationExecutor.aggregateOneAlignedSeries(AlignedPath alignedPath,
Set<String> measurements,
QueryContext context,
Filter timeFilter,
TSDataType tsDataType,
List<List<AggregateResult>> ascAggregateResultList,
List<List<AggregateResult>> descAggregateResultList,
TsFileFilter fileFilter,
boolean ascending) |
protected void |
AggregationExecutor.aggregateOneSeries(PartialPath seriesPath,
List<Integer> indexes,
Set<String> allMeasurementsInDevice,
Filter timeFilter)
get aggregation result for one series
|
static void |
AggregationExecutor.aggregateOneSeries(PartialPath seriesPath,
Set<String> measurements,
QueryContext context,
Filter timeFilter,
TSDataType tsDataType,
List<AggregateResult> ascAggregateResultList,
List<AggregateResult> descAggregateResultList,
TsFileFilter fileFilter,
boolean ascending) |
protected List<Pair<Boolean,TimeValuePair>> |
LastQueryExecutor.calculateLastPairForSeries(List<PartialPath> seriesPaths,
List<TSDataType> dataTypes,
QueryContext context,
IExpression expression,
RawDataQueryPlan lastQueryPlan) |
static List<Pair<Boolean,TimeValuePair>> |
LastQueryExecutor.calculateLastPairForSeriesLocally(List<PartialPath> seriesPaths,
List<TSDataType> dataTypes,
QueryContext context,
IExpression expression,
Map<String,Set<String>> deviceMeasurementsMap) |
protected IFill |
FillQueryExecutor.configureFill(IFill fill,
PartialPath path,
TSDataType dataType,
long queryTime,
Set<String> deviceMeasurements,
QueryContext context) |
QueryDataSet |
FillQueryExecutor.execute(QueryContext context)
execute fill.
|
QueryDataSet |
LastQueryExecutor.execute(QueryContext context,
LastQueryPlan lastQueryPlan)
execute last function
|
QueryDataSet |
UDFQueryExecutor.executeFromAlignedDataSet(QueryContext context,
QueryDataSet sourceDataSet,
List<TSDataType> fieldTypes,
boolean keepNull) |
QueryDataSet |
RawDataQueryExecutor.executeNonAlign(QueryContext context) |
QueryDataSet |
AggregationExecutor.executeWithoutValueFilter(AggregationPlan aggregationPlan)
execute aggregate function with only time filter or no filter.
|
QueryDataSet |
RawDataQueryExecutor.executeWithoutValueFilter(QueryContext context)
without filter or with global time filter.
|
QueryDataSet |
UDFQueryExecutor.executeWithoutValueFilterAlignByTime(QueryContext context) |
QueryDataSet |
UDFQueryExecutor.executeWithoutValueFilterNonAlign(QueryContext context) |
QueryDataSet |
AggregationExecutor.executeWithValueFilter(AggregationPlan queryPlan)
execute aggregate function with value filter.
|
QueryDataSet |
RawDataQueryExecutor.executeWithValueFilter(QueryContext context)
executeWithValueFilter query.
|
QueryDataSet |
UDFQueryExecutor.executeWithValueFilterAlignByTime(QueryContext context) |
QueryDataSet |
UDFQueryExecutor.executeWithValueFilterNonAlign(QueryContext context) |
QueryDataSet |
IQueryRouter.fill(FillQueryPlan fillQueryPlan,
QueryContext context)
Execute fill query.
|
QueryDataSet |
QueryRouter.fill(FillQueryPlan fillQueryPlan,
QueryContext context) |
protected IReaderByTimestamp |
AggregationExecutor.getReaderByTime(PartialPath path,
RawDataQueryPlan queryPlan,
TSDataType dataType,
QueryContext context) |
protected IReaderByTimestamp |
RawDataQueryExecutor.getReaderByTimestamp(PartialPath path,
Set<String> allSensors,
TSDataType dataType,
QueryContext context) |
protected List<TimeValuePair> |
FillQueryExecutor.getTimeValuePairs(QueryContext context) |
QueryDataSet |
IQueryRouter.groupBy(GroupByTimePlan groupByTimePlan,
QueryContext context)
Execute groupBy query.
|
QueryDataSet |
QueryRouter.groupBy(GroupByTimePlan groupByTimePlan,
QueryContext context) |
QueryDataSet |
IQueryRouter.groupByFill(GroupByTimeFillPlan groupByFillPlan,
QueryContext context)
Execute group by fill query
|
QueryDataSet |
QueryRouter.groupByFill(GroupByTimeFillPlan groupByFillPlan,
QueryContext context) |
protected List<ManagedSeriesReader> |
RawDataQueryExecutor.initManagedSeriesReader(QueryContext context) |
protected Pair<List<IReaderByTimestamp>,List<List<Integer>>> |
RawDataQueryExecutor.initSeriesReaderByTimestamp(QueryContext context,
RawDataQueryPlan queryPlan,
List<Boolean> cached,
Filter timeFilter)
init IReaderByTimestamp for each not cached PartialPath, if it's already been cached, the
corresponding IReaderByTimestamp will be null group these not cached PartialPath to one
AlignedPath if they belong to same aligned device
|
QueryDataSet |
IQueryRouter.lastQuery(LastQueryPlan lastQueryPlan,
QueryContext context)
Execute last query
|
QueryDataSet |
QueryRouter.lastQuery(LastQueryPlan lastQueryPlan,
QueryContext context) |
protected QueryDataSet |
RawDataQueryExecutor.needRedirect(QueryContext context,
boolean hasValueFilter)
Check whether need to redirect query to other node.
|
QueryDataSet |
IQueryRouter.rawDataQuery(RawDataQueryPlan queryPlan,
QueryContext context)
Execute physical plan.
|
QueryDataSet |
QueryRouter.rawDataQuery(RawDataQueryPlan queryPlan,
QueryContext context) |
QueryDataSet |
IQueryRouter.udafQuery(UDAFPlan udafPlan,
QueryContext context)
Execute UDAF query.
|
QueryDataSet |
QueryRouter.udafQuery(UDAFPlan udafPlan,
QueryContext context) |
QueryDataSet |
IQueryRouter.udtfQuery(UDTFPlan udtfPlan,
QueryContext context)
Execute UDTF query
|
QueryDataSet |
QueryRouter.udtfQuery(UDTFPlan udtfPlan,
QueryContext context) |
| 限定符和类型 | 方法和说明 |
|---|---|
protected TimeValuePair |
LinearFill.calculatePrecedingPoint() |
protected TimeValuePair |
LinearFill.calculateSucceedingPoint() |
abstract void |
IFill.configureFill(PartialPath path,
TSDataType dataType,
long queryTime,
Set<String> deviceMeasurements,
QueryContext context) |
void |
PreviousFill.configureFill(PartialPath path,
TSDataType dataType,
long queryTime,
Set<String> sensors,
QueryContext context) |
TimeValuePair |
LinearFill.getFillResult() |
abstract TimeValuePair |
IFill.getFillResult() |
TimeValuePair |
PreviousFill.getFillResult() |
TimeValuePair |
ValueFill.getSpecifiedFillResult(TSDataType dataType) |
| 限定符和类型 | 方法和说明 |
|---|---|
abstract IntermediateLayer |
Expression.constructIntermediateLayer(long queryId,
UDTFPlan udtfPlan,
RawQueryInputLayer rawTimeSeriesInputLayer,
Map<Expression,IntermediateLayer> expressionIntermediateLayerMap,
Map<Expression,TSDataType> expressionDataTypeMap,
LayerMemoryAssigner memoryAssigner) |
| 限定符和类型 | 方法和说明 |
|---|---|
IntermediateLayer |
BinaryExpression.constructIntermediateLayer(long queryId,
UDTFPlan udtfPlan,
RawQueryInputLayer rawTimeSeriesInputLayer,
Map<Expression,IntermediateLayer> expressionIntermediateLayerMap,
Map<Expression,TSDataType> expressionDataTypeMap,
LayerMemoryAssigner memoryAssigner) |
| 构造器和说明 |
|---|
ConstantOperand(TSDataType dataType,
String str) |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
ServerTimeGenerator.serverConstructNode(IExpression expression) |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
PointCollector.putBinary(long timestamp,
Binary value)
Collects a Binary data point with timestamp.
|
void |
PointCollector.putString(long timestamp,
String value)
Collects a String data point with timestamp.
|
| 限定符和类型 | 方法和说明 |
|---|---|
void |
UDFConfigurations.check() |
void |
UDTFConfigurations.check() |
| 构造器和说明 |
|---|
UDFParameters(FunctionExpression functionExpression,
Map<Expression,TSDataType> expressionDataTypeMap) |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
AccessStrategy.check()
Used by the system to check the access strategy.
|
void |
SlidingSizeWindowAccessStrategy.check() |
void |
SlidingTimeWindowAccessStrategy.check() |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
UDTFSelectK.terminate(PointCollector collector) |
void |
UDTFCast.transform(Row row,
PointCollector collector) |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
UDTFExecutor.beforeStart(long queryId,
float collectorMemoryBudgetInMB,
Map<Expression,TSDataType> expressionDataTypeMap) |
void |
UDTFExecutor.execute(Row row,
boolean isCurrentRowNull) |
void |
UDTFExecutor.execute(RowWindow rowWindow) |
void |
UDTFExecutor.terminate() |
| 构造器和说明 |
|---|
ConstantIntermediateLayer(ConstantOperand expression,
long queryId,
float memoryBudgetInMB) |
MultiInputColumnIntermediateLayer(Expression expression,
long queryId,
float memoryBudgetInMB,
List<LayerPointReader> parentLayerPointReaders) |
RawQueryInputLayer(long queryId,
float memoryBudgetInMB,
IUDFInputDataSet queryDataSet) |
RawQueryInputLayer(long queryId,
float memoryBudgetInMB,
List<PartialPath> paths,
List<TSDataType> dataTypes,
TimeGenerator timeGenerator,
List<IReaderByTimestamp> readers,
List<List<Integer>> readerToIndexList,
List<Boolean> cached)
InputLayerWithValueFilter
|
RawQueryInputLayer(long queryId,
float memoryBudgetInMB,
UDTFPlan queryPlan,
List<ManagedSeriesReader> readers)
InputLayerWithoutValueFilter
|
SingleInputColumnMultiReferenceIntermediateLayer(Expression expression,
long queryId,
float memoryBudgetInMB,
LayerPointReader parentLayerPointReader) |
| 限定符和类型 | 方法和说明 |
|---|---|
boolean |
LayerPointReader.next() |
boolean |
LayerRowReader.next() |
boolean |
LayerRowWindowReader.next() |
boolean |
ConstantLayerPointReader.next() |
void |
LayerRowWindowReader.readyForNext() |
| 构造器和说明 |
|---|
ConstantLayerPointReader(ConstantOperand expression) |
| 限定符和类型 | 方法和说明 |
|---|---|
protected boolean |
ArithmeticBinaryTransformer.cacheValue() |
protected boolean |
TransparentTransformer.cacheValue() |
protected boolean |
UDFQueryTransformer.cacheValue() |
protected boolean |
ArithmeticNegationTransformer.cacheValue() |
protected abstract boolean |
Transformer.cacheValue()
if this method returns true, at least one of the cached field should be set
|
protected boolean |
UDFQueryTransformer.cacheValueFromUDFOutput() |
protected boolean |
UDFQueryRowWindowTransformer.executeUDFOnce() |
protected boolean |
UDFQueryRowTransformer.executeUDFOnce() |
protected abstract boolean |
UDFQueryTransformer.executeUDFOnce() |
boolean |
Transformer.next() |
protected boolean |
UDFQueryTransformer.terminate() |
| 限定符和类型 | 方法和说明 |
|---|---|
protected void |
ElasticSerializableRowRecordList.applyNewMemoryControlParameters(int newByteArrayLengthForMemoryControl,
int newInternalRowRecordListCapacity) |
protected static int |
SerializableRowRecordList.calculateCapacity(TSDataType[] dataTypes,
float memoryLimitInMB,
int byteArrayLengthForMemoryControl)
Calculate the number of rows that can be cached given the memory limit.
|
protected void |
ElasticSerializableRowRecordList.checkMemoryUsage() |
void |
ElasticSerializableRowRecordList.put(Object[] rowRecord) |
| 构造器和说明 |
|---|
ElasticSerializableRowRecordList(TSDataType[] dataTypes,
long queryId,
float memoryLimitInMB,
int numCacheBlock)
Construct a ElasticSerializableRowRecordList.
|
| 限定符和类型 | 方法和说明 |
|---|---|
protected void |
ElasticSerializableBinaryTVList.applyNewMemoryControlParameters(int newByteArrayLengthForMemoryControl,
int newInternalTVListCapacity) |
protected static int |
SerializableTVList.calculateCapacity(TSDataType dataType,
float memoryLimitInMB) |
protected void |
ElasticSerializableBinaryTVList.checkMemoryUsage() |
static ElasticSerializableTVList |
ElasticSerializableTVList.newElasticSerializableTVList(TSDataType dataType,
long queryId,
float memoryLimitInMB,
int cacheSize) |
void |
ElasticSerializableTVList.put(long timestamp,
Object value) |
void |
ElasticSerializableBinaryTVList.putBinary(long timestamp,
Binary value) |
void |
ElasticSerializableTVList.putBinary(long timestamp,
Binary value) |
void |
ElasticSerializableTVList.putNull(long timestamp) |
void |
ElasticSerializableBinaryTVList.putString(long timestamp,
String value) |
void |
ElasticSerializableTVList.putString(long timestamp,
String value) |
| 构造器和说明 |
|---|
ElasticSerializableBinaryTVList(long queryId,
float memoryLimitInMB,
int cacheSize) |
ElasticSerializableTVList(TSDataType dataType,
long queryId,
float memoryLimitInMB,
int cacheSize) |
| 限定符和类型 | 方法和说明 |
|---|---|
UDF |
UDFRegistrationService.reflect(FunctionExpression expression) |
| 限定符和类型 | 方法和说明 |
|---|---|
QueryDataSet |
ServiceProvider.createQueryDataSet(QueryContext context,
PhysicalPlan physicalPlan,
int fetchSize)
create QueryDataSet and buffer it for fetchResults
|
abstract boolean |
ServiceProvider.executeNonQuery(PhysicalPlan plan) |
boolean |
StandaloneServiceProvider.executeNonQuery(PhysicalPlan plan) |
| 构造器和说明 |
|---|
ServiceProvider(PlanExecutor executor) |
StandaloneServiceProvider() |
| 限定符和类型 | 方法和说明 |
|---|---|
static Object |
CommonUtils.parseValue(TSDataType dataType,
String value) |
static Object |
CommonUtils.parseValueForTest(TSDataType dataType,
String value) |
Copyright © 2022 The Apache Software Foundation. All rights reserved.