| 异常错误 | 说明 |
|---|---|
| LogicalOperatorException |
This exception is thrown while meeting error in transforming logical operator to physical plan.
|
| LogicalOptimizeException |
This exception is thrown while meeting error in optimizing logical operator.
|
| OutOfTTLException | |
| PathException | |
| PathNumOverLimitException | |
| QueryProcessException | |
| QueryTimeoutRuntimeException |
This class is used to throw run time exception when query is time out.
|
| UnSupportedFillTypeException |
Copyright © 2022 The Apache Software Foundation. All rights reserved.