| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| LogicalOperatorException
This exception is thrown while meeting error in transforming logical operator to physical plan.
|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| LogicalOperatorException
This exception is thrown while meeting error in transforming logical operator to physical plan.
|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| LogicalOperatorException
This exception is thrown while meeting error in transforming logical operator to physical plan.
|
| PathNumOverLimitException |
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| LogicalOperatorException
This exception is thrown while meeting error in transforming logical operator to physical plan.
|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| LogicalOperatorException
This exception is thrown while meeting error in transforming logical operator to physical plan.
|
| QueryProcessException |
| 类和说明 |
|---|
| LogicalOperatorException
This exception is thrown while meeting error in transforming logical operator to physical plan.
|
| LogicalOptimizeException
This exception is thrown while meeting error in optimizing logical operator.
|
| PathNumOverLimitException |
| QueryProcessException |
| 类和说明 |
|---|
| LogicalOperatorException
This exception is thrown while meeting error in transforming logical operator to physical plan.
|
| LogicalOptimizeException
This exception is thrown while meeting error in optimizing logical operator.
|
| PathNumOverLimitException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| UnSupportedFillTypeException |
| 类和说明 |
|---|
| LogicalOptimizeException
This exception is thrown while meeting error in optimizing logical operator.
|
| QueryProcessException |
| 类和说明 |
|---|
| LogicalOptimizeException
This exception is thrown while meeting error in optimizing logical operator.
|
| QueryProcessException |
| 类和说明 |
|---|
| LogicalOptimizeException
This exception is thrown while meeting error in optimizing logical operator.
|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| QueryProcessException |
| 类和说明 |
|---|
| LogicalOperatorException
This exception is thrown while meeting error in transforming logical operator to physical plan.
|
| 类和说明 |
|---|
| QueryProcessException |
Copyright © 2022 The Apache Software Foundation. All rights reserved.