public interface IDTable
| 限定符和类型 | 字段和说明 |
|---|---|
static IoTDBConfig |
config
iotdb config
|
static org.slf4j.Logger |
logger
logger
|
| 限定符和类型 | 方法和说明 |
|---|---|
void |
clear()
clear id table and close file
|
void |
createAlignedTimeseries(CreateAlignedTimeSeriesPlan plan)
create aligned timeseries
|
void |
createTimeseries(CreateTimeSeriesPlan plan)
create timeseries
|
void |
deregisterTrigger(PartialPath fullPath,
IMeasurementMNode measurementMNode)
deregister trigger to the timeseries
|
List<DeviceEntry> |
getAllDeviceEntry()
get all device entries
|
DeviceEntry |
getDeviceEntry(String deviceName)
get device entry from device path
|
IDiskSchemaManager |
getIDiskSchemaManager() |
Map<IDeviceID,DeviceEntry>[] |
getIdTables() |
TimeValuePair |
getLastCache(TimeseriesID timeseriesID)
get last cache of the timeseies
|
IDeviceID |
getSeriesSchemas(InsertPlan plan)
check inserting timeseries existence and fill their measurement mnode
|
void |
putSchemaEntry(String devicePath,
String measurement,
SchemaEntry schemaEntry,
boolean isAligned)
put schema entry to id table, currently used in recover
|
void |
registerTrigger(PartialPath fullPath,
IMeasurementMNode measurementMNode)
register trigger to the timeseries
|
static PartialPath |
translateQueryPath(PartialPath fullPath)
translate query path's device path to device id
|
void |
updateLastCache(TimeseriesID timeseriesID,
TimeValuePair pair,
boolean highPriorityUpdate,
Long latestFlushedTime)
update last cache of the timeseies
|
static final org.slf4j.Logger logger
static final IoTDBConfig config
void createAlignedTimeseries(CreateAlignedTimeSeriesPlan plan) throws MetadataException
plan - create aligned timeseries planMetadataException - if the device is not aligned, throw itvoid createTimeseries(CreateTimeSeriesPlan plan) throws MetadataException
plan - create timeseries planMetadataException - if the device is aligned, throw itIDeviceID getSeriesSchemas(InsertPlan plan) throws MetadataException
plan - insert planMetadataException - if insert plan's aligned value is inconsistent with devicevoid registerTrigger(PartialPath fullPath, IMeasurementMNode measurementMNode) throws MetadataException
fullPath - full path of the timeseriesmeasurementMNode - the timeseries measurement mnodeMetadataException - if the timeseries is not exitsvoid deregisterTrigger(PartialPath fullPath, IMeasurementMNode measurementMNode) throws MetadataException
fullPath - full path of the timeseriesmeasurementMNode - the timeseries measurement mnodeMetadataException - if the timeseries is not exitsTimeValuePair getLastCache(TimeseriesID timeseriesID) throws MetadataException
timeseriesID - timeseries ID of the timeseriesMetadataException - if the timeseries is not exitsvoid updateLastCache(TimeseriesID timeseriesID, TimeValuePair pair, boolean highPriorityUpdate, Long latestFlushedTime) throws MetadataException
timeseriesID - timeseries ID of the timeseriespair - last time value pairhighPriorityUpdate - is high priority updatelatestFlushedTime - last flushed timeMetadataException - if the timeseries is not exitsvoid clear()
throws IOException
IOExceptionDeviceEntry getDeviceEntry(String deviceName)
deviceName - device name of the time seriesList<DeviceEntry> getAllDeviceEntry()
void putSchemaEntry(String devicePath, String measurement, SchemaEntry schemaEntry, boolean isAligned) throws MetadataException
devicePath - device path (can be device id formed path)measurement - measurement nameschemaEntry - schema entry to putisAligned - is the device alignedMetadataExceptionstatic PartialPath translateQueryPath(PartialPath fullPath)
fullPath - full query pathMap<IDeviceID,DeviceEntry>[] getIdTables()
IDiskSchemaManager getIDiskSchemaManager()
Copyright © 2022 The Apache Software Foundation. All rights reserved.