| 限定符和类型 | 字段和说明 |
|---|---|
protected static IoTDBConfig |
config
iotdb config
|
| 构造器和说明 |
|---|
IDTableHashmapImpl(File storageGroupDir) |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
clear()
clear id table and close file
|
void |
createAlignedTimeseries(CreateAlignedTimeSeriesPlan plan)
create aligned timeseries
|
void |
createTimeseries(CreateTimeSeriesPlan plan)
create timeseries
|
void |
deregisterTrigger(PartialPath fullPath,
IMeasurementMNode measurementMNode)
deregister trigger to the timeseries
|
List<DeviceEntry> |
getAllDeviceEntry()
get all device entries
|
DeviceEntry |
getDeviceEntry(String deviceName)
get device entry from device path
|
IDiskSchemaManager |
getIDiskSchemaManager() |
Map<IDeviceID,DeviceEntry>[] |
getIdTables() |
TimeValuePair |
getLastCache(TimeseriesID timeseriesID)
get last cache of the timeseies
|
IDeviceID |
getSeriesSchemas(InsertPlan plan)
check inserting timeseries existence and fill their measurement mnode
|
void |
putSchemaEntry(String devicePath,
String measurement,
SchemaEntry schemaEntry,
boolean isAligned)
put schema entry to id table, currently used in recover
|
void |
registerTrigger(PartialPath fullPath,
IMeasurementMNode measurementMNode)
register trigger to the timeseries
|
void |
updateLastCache(TimeseriesID timeseriesID,
TimeValuePair pair,
boolean highPriorityUpdate,
Long latestFlushedTime)
update last cache of the timeseies
|
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waittranslateQueryPathprotected static IoTDBConfig config
public IDTableHashmapImpl(File storageGroupDir)
public void createAlignedTimeseries(CreateAlignedTimeSeriesPlan plan) throws MetadataException
createAlignedTimeseries 在接口中 IDTableplan - create aligned timeseries planMetadataException - if the device is not aligned, throw itpublic void createTimeseries(CreateTimeSeriesPlan plan) throws MetadataException
createTimeseries 在接口中 IDTableplan - create timeseries planMetadataException - if the device is aligned, throw itpublic IDeviceID getSeriesSchemas(InsertPlan plan) throws MetadataException
getSeriesSchemas 在接口中 IDTableplan - insert planMetadataException - if insert plan's aligned value is inconsistent with devicepublic void registerTrigger(PartialPath fullPath, IMeasurementMNode measurementMNode) throws MetadataException
registerTrigger 在接口中 IDTablefullPath - full path of the timeseriesmeasurementMNode - the timeseries measurement mnodeMetadataException - if the timeseries is not exitspublic void deregisterTrigger(PartialPath fullPath, IMeasurementMNode measurementMNode) throws MetadataException
deregisterTrigger 在接口中 IDTablefullPath - full path of the timeseriesmeasurementMNode - the timeseries measurement mnodeMetadataException - if the timeseries is not exitspublic TimeValuePair getLastCache(TimeseriesID timeseriesID) throws MetadataException
getLastCache 在接口中 IDTabletimeseriesID - timeseries ID of the timeseriesMetadataException - if the timeseries is not exitspublic void updateLastCache(TimeseriesID timeseriesID, TimeValuePair pair, boolean highPriorityUpdate, Long latestFlushedTime) throws MetadataException
updateLastCache 在接口中 IDTabletimeseriesID - timeseries ID of the timeseriespair - last time value pairhighPriorityUpdate - is high priority updatelatestFlushedTime - last flushed timeMetadataException - if the timeseries is not exitspublic void clear()
throws IOException
IDTableclear 在接口中 IDTableIOExceptionpublic DeviceEntry getDeviceEntry(String deviceName)
getDeviceEntry 在接口中 IDTabledeviceName - device name of the time seriespublic List<DeviceEntry> getAllDeviceEntry()
IDTablegetAllDeviceEntry 在接口中 IDTablepublic void putSchemaEntry(String devicePath, String measurement, SchemaEntry schemaEntry, boolean isAligned) throws MetadataException
IDTableputSchemaEntry 在接口中 IDTabledevicePath - device path (can be device id formed path)measurement - measurement nameschemaEntry - schema entry to putisAligned - is the device alignedMetadataExceptionpublic Map<IDeviceID,DeviceEntry>[] getIdTables()
getIdTables 在接口中 IDTablepublic IDiskSchemaManager getIDiskSchemaManager()
getIDiskSchemaManager 在接口中 IDTableCopyright © 2022 The Apache Software Foundation. All rights reserved.