| 接口 | 说明 |
|---|---|
| IDiskSchemaManager |
This class manages IO of id table's schema entry
|
| IDTable |
| 类 | 说明 |
|---|---|
| AppendOnlyDiskSchemaManager |
store id table schema in append only file
|
| IDTableHashmapImpl |
id table belongs to a storage group and mapping timeseries path to it's schema
|
| IDTableManager |
This class manages one id table for each logical storage group
|
Copyright © 2022 The Apache Software Foundation. All rights reserved.