public class LastCacheManager extends Object
| 构造器和说明 |
|---|
LastCacheManager() |
| 限定符和类型 | 方法和说明 |
|---|---|
static void |
checkTTLOnLastCache(IMNode node,
long dataTTL) |
static void |
deleteLastCacheByDevice(IEntityMNode node)
delete all the last cache value of any timeseries or aligned timeseries under the entity
|
static void |
deleteLastCacheByDevice(IEntityMNode node,
PartialPath originalPath,
long startTime,
long endTime)
delete the last cache value of timeseries or subMeasurement of some aligned timeseries, which
is under the entity and matching the originalPath
|
static TimeValuePair |
getLastCache(IMeasurementMNode node)
get the last cache value of time series of given seriesPath
|
static long |
getLastTimeStamp(IMeasurementMNode node,
QueryContext queryContext)
get the last value of timeseries represented by given measurementMNode get last value from
cache in measurementMNode if absent, get last value from file
|
static void |
resetLastCache(IMeasurementMNode node)
reset the last cache value of time series of given seriesPath
|
static void |
updateLastCache(IMeasurementMNode node,
TimeValuePair timeValuePair,
boolean highPriorityUpdate,
Long latestFlushedTime)
update the last cache value of time series of given seriesPath
|
public static TimeValuePair getLastCache(IMeasurementMNode node)
node - the measurementMNode holding the lastCache When invoker only has the target
seriesPath, the node could be null and MManager will search the nodepublic static void updateLastCache(IMeasurementMNode node, TimeValuePair timeValuePair, boolean highPriorityUpdate, Long latestFlushedTime)
node - the measurementMNode holding the lastCache When invoker only has the target
seriesPath, the node could be null and MManager will search the nodetimeValuePair - the latest point valuehighPriorityUpdate - the last value from insertPlan is high prioritylatestFlushedTime - latest flushed timepublic static void resetLastCache(IMeasurementMNode node)
node - the measurementMNode holding the lastCache When invoker only has the target
seriesPath, the node could be null and MManager will search the nodepublic static void deleteLastCacheByDevice(IEntityMNode node)
node - entity nodepublic static void deleteLastCacheByDevice(IEntityMNode node, PartialPath originalPath, long startTime, long endTime)
node - entity nodeoriginalPath - origin timeseries pathstartTime - startTimeendTime - endTimepublic static long getLastTimeStamp(IMeasurementMNode node, QueryContext queryContext)
node - measurementMNode representing the target timeseriesqueryContext - query contextpublic static void checkTTLOnLastCache(IMNode node, long dataTTL)
Copyright © 2022 The Apache Software Foundation. All rights reserved.