| 限定符和类型 | 方法和说明 |
|---|---|
IMNode |
MManager.getDeviceNode(PartialPath path) |
protected IMNode |
MManager.getDeviceNodeWithAutoCreate(PartialPath path) |
protected IMNode |
MManager.getDeviceNodeWithAutoCreate(PartialPath path,
boolean autoCreateSchema,
boolean allowCreateSg,
int sgLevel)
get device node, if the storage group is not set, create it when autoCreateSchema is true
(we develop this method as we need to get the node's lock after we get the lock.writeLock())
|
IMNode |
MManager.getSeriesSchemasAndReadLockDevice(InsertPlan plan)
get schema for device.
|
| 限定符和类型 | 方法和说明 |
|---|---|
protected IMeasurementMNode |
MManager.getMeasurementMNode(IMNode deviceMNode,
String measurementName)
Invoked during insertPlan process.
|
| 限定符和类型 | 类和说明 |
|---|---|
class |
InsertMeasurementMNode
Generated entity implements IMeasurementMNode interface to unify insert logic through id table
and mmanager
|
| 限定符和类型 | 方法和说明 |
|---|---|
IMNode |
InsertMeasurementMNode.addChild(IMNode child) |
IMNode |
InsertMeasurementMNode.getChild(String name) |
| 限定符和类型 | 方法和说明 |
|---|---|
Map<String,IMNode> |
InsertMeasurementMNode.getChildren() |
| 限定符和类型 | 方法和说明 |
|---|---|
IMNode |
InsertMeasurementMNode.addChild(IMNode child) |
void |
InsertMeasurementMNode.addChild(String name,
IMNode child) |
void |
InsertMeasurementMNode.replaceChild(String oldChildName,
IMNode newChildNode) |
void |
InsertMeasurementMNode.setParent(IMNode parent) |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
InsertMeasurementMNode.setChildren(Map<String,IMNode> children) |
| 限定符和类型 | 方法和说明 |
|---|---|
static void |
LastCacheManager.checkTTLOnLastCache(IMNode node,
long dataTTL) |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
MLogWriter.serializeMNode(IMNode node) |
| 限定符和类型 | 接口和说明 |
|---|---|
interface |
IEntityMNode |
interface |
IMeasurementMNode
This interface defines a MeasurementMNode's operation interfaces.
|
interface |
IStorageGroupMNode
This interface defines a StorageGroupMNode's operation interfaces.
|
| 限定符和类型 | 类和说明 |
|---|---|
class |
EntityMNode |
class |
InternalMNode
This class is the implementation of Metadata Node.
|
class |
MeasurementMNode |
class |
MNode |
class |
StorageGroupEntityMNode |
class |
StorageGroupMNode |
| 限定符和类型 | 字段和说明 |
|---|---|
protected IMNode |
MNode.parent |
| 限定符和类型 | 字段和说明 |
|---|---|
protected Map<String,IMNode> |
InternalMNode.children
use in Measurement Node so it's protected suppress warnings reason: volatile for double
synchronized check
This will be a ConcurrentHashMap instance
|
| 限定符和类型 | 方法和说明 |
|---|---|
IMNode |
IMNode.addChild(IMNode child) |
IMNode |
InternalMNode.addChild(IMNode child)
Add a child to the current mnode.
|
IMNode |
MeasurementMNode.addChild(IMNode child) |
IMNode |
IMNode.getChild(String name) |
IMNode |
InternalMNode.getChild(String name)
get the child with the name
|
IMNode |
MeasurementMNode.getChild(String name) |
IMNode |
EntityMNode.getChild(String name)
get the child with the name
|
IMNode |
IMNode.getParent() |
IMNode |
MNode.getParent() |
static IMNode |
MNodeUtils.setToInternal(IEntityMNode entityMNode)
When there's no measurement, represented by template or MeasurementMNode, is under this
entityMNode, it should not act as entity anymore.
|
| 限定符和类型 | 方法和说明 |
|---|---|
Map<String,IMNode> |
IMNode.getChildren() |
Map<String,IMNode> |
InternalMNode.getChildren() |
Map<String,IMNode> |
MeasurementMNode.getChildren() |
| 限定符和类型 | 方法和说明 |
|---|---|
IMNode |
IMNode.addChild(IMNode child) |
IMNode |
InternalMNode.addChild(IMNode child)
Add a child to the current mnode.
|
IMNode |
MeasurementMNode.addChild(IMNode child) |
void |
IMNode.addChild(String name,
IMNode child) |
void |
InternalMNode.addChild(String name,
IMNode child)
add a child to current mnode
|
void |
MeasurementMNode.addChild(String name,
IMNode child) |
void |
IMNode.replaceChild(String oldChildName,
IMNode newChildNode) |
void |
InternalMNode.replaceChild(String oldChildName,
IMNode newChildNode)
Replace a child of this mnode.
|
void |
MeasurementMNode.replaceChild(String oldChildName,
IMNode newChildNode) |
void |
IMNode.setParent(IMNode parent) |
void |
MNode.setParent(IMNode parent) |
static IEntityMNode |
MNodeUtils.setToEntity(IMNode node)
When a measurement, represented by template or MeasurementMNode, is going to be added to a
node, the node should be set to entity.
|
| 限定符和类型 | 方法和说明 |
|---|---|
void |
IMNode.setChildren(Map<String,IMNode> children) |
void |
InternalMNode.setChildren(Map<String,IMNode> children) |
void |
MeasurementMNode.setChildren(Map<String,IMNode> children) |
| 构造器和说明 |
|---|
EntityMNode(IMNode parent,
String name)
Constructor of MNode.
|
InternalMNode(IMNode parent,
String name)
Constructor of MNode.
|
MNode(IMNode parent,
String name)
Constructor of MNode.
|
StorageGroupEntityMNode(IMNode parent,
String name,
long dataTTL) |
StorageGroupMNode(IMNode parent,
String name,
long dataTTL) |
| 限定符和类型 | 方法和说明 |
|---|---|
IMNode |
MTree.checkTemplateAlignmentWithMountedNode(IMNode mountedNode,
Template template)
Check route 1: If template has no direct measurement, just pass the check.
|
IMNode |
MTree.getDeviceNodeWithAutoCreating(PartialPath deviceId,
int sgLevel)
Add an interval path to MTree.
|
IMNode |
MTree.getNodeByPath(PartialPath path)
Get node by the path
|
IMNode |
MTree.getNodeByPathWithStorageGroupCheck(PartialPath path)
Get node by path with storage group check If storage group is not set,
StorageGroupNotSetException will be thrown
|
| 限定符和类型 | 方法和说明 |
|---|---|
IMNode |
MTree.checkTemplateAlignmentWithMountedNode(IMNode mountedNode,
Template template)
Check route 1: If template has no direct measurement, just pass the check.
|
void |
MTree.checkTemplateInUseOnLowerNode(IMNode node) |
IEntityMNode |
MTree.setToEntity(IMNode node) |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
MTree.processMNodeDuringTraversal(PartialPath pathPattern,
BiConsumer<IMNode,Long> consumer) |
| 限定符和类型 | 字段和说明 |
|---|---|
protected IMNode |
Traverser.startNode |
| 限定符和类型 | 字段和说明 |
|---|---|
protected Deque<IMNode> |
Traverser.traverseContext |
| 限定符和类型 | 方法和说明 |
|---|---|
protected IMNode |
Traverser.getStorageGroupNodeInTraversePath() |
| 限定符和类型 | 方法和说明 |
|---|---|
protected PartialPath |
Traverser.getCurrentPartialPath(IMNode currentNode) |
protected abstract boolean |
Traverser.processFullMatchedMNode(IMNode node,
int idx,
int level)
full match: root.sg.d full match root.sg.
|
protected abstract boolean |
Traverser.processInternalMatchedMNode(IMNode node,
int idx,
int level)
internal match: root.sg internal match root.sg.
|
protected void |
Traverser.processMultiLevelWildcard(IMNode node,
int idx,
int level) |
protected void |
Traverser.processNameMatch(IMNode node,
int idx,
int level) |
protected void |
Traverser.processOneLevelWildcard(IMNode node,
int idx,
int level) |
protected void |
Traverser.traverse(IMNode node,
int idx,
int level)
The recursive method for MTree traversal.
|
| 构造器和说明 |
|---|
Traverser(IMNode startNode,
PartialPath path)
To traverse subtree under root.sg, e.g., init Traverser(root, "root.sg.**")
|
| 限定符和类型 | 方法和说明 |
|---|---|
protected boolean |
MNodeCollector.processFullMatchedMNode(IMNode node,
int idx,
int level) |
protected boolean |
MeasurementCollector.processFullMatchedMNode(IMNode node,
int idx,
int level) |
protected boolean |
EntityCollector.processFullMatchedMNode(IMNode node,
int idx,
int level) |
protected boolean |
StorageGroupCollector.processFullMatchedMNode(IMNode node,
int idx,
int level) |
protected boolean |
MNodeCollector.processInternalMatchedMNode(IMNode node,
int idx,
int level) |
protected boolean |
MeasurementCollector.processInternalMatchedMNode(IMNode node,
int idx,
int level) |
protected boolean |
EntityCollector.processInternalMatchedMNode(IMNode node,
int idx,
int level) |
protected boolean |
StorageGroupCollector.processInternalMatchedMNode(IMNode node,
int idx,
int level) |
protected abstract void |
MNodeCollector.transferToResult(IMNode node) |
protected void |
MNodeCollector.traverse(IMNode node,
int idx,
int level) |
protected void |
CollectorTraverser.traverse(IMNode node,
int idx,
int level)
extends traversal with limit restriction
|
| 构造器和说明 |
|---|
CollectorTraverser(IMNode startNode,
PartialPath path) |
CollectorTraverser(IMNode startNode,
PartialPath path,
int limit,
int offset) |
EntityCollector(IMNode startNode,
PartialPath path) |
EntityCollector(IMNode startNode,
PartialPath path,
int limit,
int offset) |
MeasurementCollector(IMNode startNode,
PartialPath path) |
MeasurementCollector(IMNode startNode,
PartialPath path,
int limit,
int offset) |
MNodeCollector(IMNode startNode,
PartialPath path) |
StorageGroupCollector(IMNode startNode,
PartialPath path) |
| 限定符和类型 | 方法和说明 |
|---|---|
protected boolean |
MNodeLevelCounter.processFullMatchedMNode(IMNode node,
int idx,
int level) |
protected boolean |
EntityCounter.processFullMatchedMNode(IMNode node,
int idx,
int level) |
protected boolean |
MeasurementGroupByLevelCounter.processFullMatchedMNode(IMNode node,
int idx,
int level) |
protected boolean |
StorageGroupCounter.processFullMatchedMNode(IMNode node,
int idx,
int level) |
protected boolean |
MeasurementCounter.processFullMatchedMNode(IMNode node,
int idx,
int level) |
protected boolean |
MNodeLevelCounter.processInternalMatchedMNode(IMNode node,
int idx,
int level) |
protected boolean |
EntityCounter.processInternalMatchedMNode(IMNode node,
int idx,
int level) |
protected boolean |
MeasurementGroupByLevelCounter.processInternalMatchedMNode(IMNode node,
int idx,
int level) |
protected boolean |
StorageGroupCounter.processInternalMatchedMNode(IMNode node,
int idx,
int level) |
protected boolean |
MeasurementCounter.processInternalMatchedMNode(IMNode node,
int idx,
int level) |
| 构造器和说明 |
|---|
CounterTraverser(IMNode startNode,
PartialPath path) |
EntityCounter(IMNode startNode,
PartialPath path) |
MeasurementCounter(IMNode startNode,
PartialPath path) |
MeasurementGroupByLevelCounter(IMNode startNode,
PartialPath path,
int groupByLevel) |
MNodeLevelCounter(IMNode startNode,
PartialPath path,
int targetLevel) |
StorageGroupCounter(IMNode startNode,
PartialPath path) |
| 限定符和类型 | 方法和说明 |
|---|---|
IMNode |
Template.getDirectNode(String nodeName) |
IMNode |
Template.getPathNodeInTemplate(String path) |
| 限定符和类型 | 方法和说明 |
|---|---|
Collection<IMNode> |
Template.getDirectNodes() |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
TemplateManager.checkTemplateCompatible(Template template,
IMNode node) |
boolean |
Template.markStorageGroup(IMNode setNode) |
boolean |
Template.unmarkStorageGroup(IMNode unsetNode) |
| 限定符和类型 | 方法和说明 |
|---|---|
static void |
MetaUtils.collectLastNode(IMNode node,
List<IMNode> lastNodeList) |
static List<String> |
MetaUtils.getMultiFullPaths(IMNode node) |
| 限定符和类型 | 方法和说明 |
|---|---|
static void |
MetaUtils.collectLastNode(IMNode node,
List<IMNode> lastNodeList) |
Copyright © 2022 The Apache Software Foundation. All rights reserved.