public class PartialPath extends Path implements Comparable<Path>, Cloneable
| 构造器和说明 |
|---|
PartialPath() |
PartialPath(String path)
Construct the PartialPath using a String, will split the given String into String[] E.g., path
= "root.sg.
|
PartialPath(String[] partialNodes) |
PartialPath(String path,
boolean needSplit) |
PartialPath(String device,
String measurement) |
getColumnNum, setMeasurementprotected String[] nodes
public PartialPath()
public PartialPath(String path) throws IllegalPathException
path - a full String of a time series pathIllegalPathExceptionpublic PartialPath(String device, String measurement) throws IllegalPathException
public PartialPath(String[] partialNodes)
partialNodes - nodes of a time series pathpublic PartialPath(String path, boolean needSplit)
path - pathneedSplit - needSplit is basically false, whether need to be split to device and
measurement, doesn't support escape character yet.public PartialPath concatPath(PartialPath partialPath)
partialPath - the path you want to concatpublic void concatPath(String[] otherNodes)
otherNodes - nodespublic PartialPath concatNode(String node)
public String[] getNodes()
public int getNodeLength()
public String getTailNode()
public List<PartialPath> alterPrefixPath(PartialPath prefix)
For example, minimizing "root.**.b.c" with prefix "root.a.b" produces "root.a.b.c", "root.a.b.b.c", "root.a.b.**.b.c", since the multi-level wildcard can match 'a', 'a.b', and any other sub paths start with 'a.b'.
The goal of this method is to reduce the search space when querying a storage group with a path with wildcard.
prefix - The prefix. Cannot be null and cannot contain any wildcard.public boolean matchFullPath(PartialPath rPath)
rPath - a plain full path of a timeseriespublic boolean matchPrefixPath(PartialPath rPath)
rPath - a plain full path of a timeseriespublic String getFullPath()
getFullPath 在类中 Pathpublic PartialPath copy()
public String getMeasurement()
getMeasurement 在类中 Pathpublic String getFirstNode()
public String getMeasurementAlias()
public void setMeasurementAlias(String measurementAlias)
public boolean isMeasurementAliasExists()
public String getFullPathWithAlias()
getFullPathWithAlias 在类中 Pathpublic IMeasurementSchema getMeasurementSchema() throws MetadataException
public TSDataType getSeriesType() throws UnsupportedOperationException
public int compareTo(Path path)
compareTo 在接口中 Comparable<Path>compareTo 在类中 Pathpublic boolean startsWith(String[] otherNodes)
public PartialPath getDevicePath()
public Path toTSFilePath()
public static List<String> toStringList(List<PartialPath> pathList)
public static List<PartialPath> fromStringList(List<String> pathList)
pathList - public LastPointReader createLastPointReader(TSDataType dataType, Set<String> deviceMeasurements, QueryContext context, QueryDataSource dataSource, long queryTime, Filter timeFilter)
public SeriesReader createSeriesReader(Set<String> allSensors, TSDataType dataType, QueryContext context, QueryDataSource dataSource, Filter timeFilter, Filter valueFilter, TsFileFilter fileFilter, boolean ascending)
public SeriesReader createSeriesReader(Set<String> allSensors, TSDataType dataType, QueryContext context, List<TsFileResource> seqFileResource, List<TsFileResource> unseqFileResource, Filter timeFilter, Filter valueFilter, boolean ascending)
public TsFileResource createTsFileResource(List<ReadOnlyMemChunk> readOnlyMemChunk, List<IChunkMetadata> chunkMetadataList, TsFileResource originTsFileResource) throws IOException
IOExceptionpublic ITimeSeriesMetadata generateTimeSeriesMetadata(List<ReadOnlyMemChunk> readOnlyMemChunk, List<IChunkMetadata> chunkMetadataList) throws IOException
IOExceptionpublic ReadOnlyMemChunk getReadOnlyMemChunkFromMemTable(IMemTable memTable, List<Pair<Modification,IMemTable>> modsToMemtable, long timeLowerBound) throws QueryProcessException, IOException
QueryProcessExceptionIOExceptionprotected List<Modification> getModificationsForMemtable(IMemTable memTable, List<Pair<Modification,IMemTable>> modsToMemtable)
public PartialPath clone()
public List<IChunkMetadata> getVisibleMetadataListFromWriter(RestorableTsFileIOWriter writer, TsFileResource tsFileResource, QueryContext context)
Copyright © 2022 The Apache Software Foundation. All rights reserved.