| 限定符和类型 | 方法和说明 |
|---|---|
List<MeasurementPath> |
MManager.getAllMeasurementByDevicePath(PartialPath devicePath) |
List<MeasurementPath> |
MManager.getMeasurementPaths(PartialPath pathPattern)
Return all measurement paths for given path if the path is abstract.
|
List<MeasurementPath> |
MManager.getMeasurementPaths(PartialPath pathPattern,
boolean isPrefixMatch)
Return all measurement paths for given path if the path is abstract.
|
Pair<List<MeasurementPath>,Integer> |
MManager.getMeasurementPathsWithAlias(PartialPath pathPattern,
int limit,
int offset,
boolean isPrefixMatch)
Similar to method getMeasurementPaths(), but return Path with alias and filter the result by
limit and offset.
|
| 限定符和类型 | 方法和说明 |
|---|---|
MeasurementPath |
InsertMeasurementMNode.getMeasurementPath() |
| 限定符和类型 | 方法和说明 |
|---|---|
MeasurementPath |
IMeasurementMNode.getMeasurementPath() |
MeasurementPath |
MeasurementMNode.getMeasurementPath()
get MeasurementPath of this node
|
| 限定符和类型 | 方法和说明 |
|---|---|
List<MeasurementPath> |
MTree.getMeasurementPaths(PartialPath pathPattern)
Get all measurement paths matching the given path pattern
|
List<MeasurementPath> |
MTree.getMeasurementPaths(PartialPath pathPattern,
boolean isPrefixMatch)
Get all measurement paths matching the given path pattern.
|
Pair<List<MeasurementPath>,Integer> |
MTree.getMeasurementPathsWithAlias(PartialPath pathPattern,
int limit,
int offset)
Get all measurement paths matching the given path pattern
|
Pair<List<MeasurementPath>,Integer> |
MTree.getMeasurementPathsWithAlias(PartialPath pathPattern,
int limit,
int offset,
boolean isPrefixMatch)
Get all measurement paths matching the given path pattern If using prefix match, the path
pattern is used to match prefix path.
|
| 限定符和类型 | 方法和说明 |
|---|---|
protected MeasurementPath |
MeasurementCollector.getCurrentMeasurementPathInTraverse(IMeasurementMNode currentNode)
When traverse goes into a template, IMNode.getPartialPath may not work as nodes in template has
no parent on MTree.
|
| 限定符和类型 | 方法和说明 |
|---|---|
MeasurementPath |
MeasurementPath.clone() |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
AlignedPath.addMeasurement(MeasurementPath measurementPath) |
| 构造器和说明 |
|---|
AlignedPath(MeasurementPath path) |
| 限定符和类型 | 方法和说明 |
|---|---|
protected List<MeasurementPath> |
PlanExecutor.getPathsName(PartialPath path) |
| 限定符和类型 | 方法和说明 |
|---|---|
protected List<MeasurementPath> |
QueryOperator.getMatchedTimeseries(PartialPath path) |
| 限定符和类型 | 字段和说明 |
|---|---|
protected List<MeasurementPath> |
QueryPlan.paths |
| 限定符和类型 | 方法和说明 |
|---|---|
List<MeasurementPath> |
SelectIntoPlan.getPaths()
mainly for query auth.
|
List<MeasurementPath> |
QueryPlan.getPaths() |
| 限定符和类型 | 方法和说明 |
|---|---|
List<MeasurementPath> |
WildcardsRemover.removeWildcardFrom(PartialPath path) |
| 限定符和类型 | 方法和说明 |
|---|---|
static TSDataType |
SchemaUtils.getSeriesTypeByPath(MeasurementPath path,
String aggregation) |
| 限定符和类型 | 方法和说明 |
|---|---|
static List<TSDataType> |
SchemaUtils.getSeriesTypesByPaths(List<MeasurementPath> paths,
List<String> aggregations) |
Copyright © 2022 The Apache Software Foundation. All rights reserved.