public class MetaUtils extends Object
| 限定符和类型 | 方法和说明 |
|---|---|
static void |
collectLastNode(IMNode node,
List<IMNode> lastNodeList) |
static List<String> |
getMultiFullPaths(IMNode node) |
static PartialPath |
getStorageGroupPathByLevel(PartialPath path,
int level)
Get storage group path when creating schema automatically is enable
e.g., path = root.a.b.c and level = 1, return root.a
|
static Map<PartialPath,List<Integer>> |
groupAggregationsBySeries(List<? extends Path> selectedPaths)
Merge same series and convert to series map.
|
static List<PartialPath> |
groupAlignedPaths(List<PartialPath> fullPaths)
PartialPath of aligned time series will be organized to one AlignedPath.
|
static Map<AlignedPath,List<List<Integer>>> |
groupAlignedSeriesWithAggregations(Map<PartialPath,List<Integer>> pathToAggrIndexesMap)
Group all the series under an aligned entity into one AlignedPath and remove these series from
pathToAggrIndexesMap.
|
static String[] |
splitPathToDetachedPath(String path) |
public static String[] splitPathToDetachedPath(String path) throws IllegalPathException
path - the path will split. ex, root.ln.IllegalPathException - if path isn't correct, the exception will throwpublic static PartialPath getStorageGroupPathByLevel(PartialPath path, int level) throws MetadataException
e.g., path = root.a.b.c and level = 1, return root.a
path - pathlevel - levelMetadataExceptionpublic static List<PartialPath> groupAlignedPaths(List<PartialPath> fullPaths)
fullPaths - full path list without uniting the sub measurement under the same aligned time
series. The list has been sorted by the alphabetical order, so all the aligned time series
of one device has already been placed contiguously.public static Map<PartialPath,List<Integer>> groupAggregationsBySeries(List<? extends Path> selectedPaths)
selectedPaths - selected seriespublic static Map<AlignedPath,List<List<Integer>>> groupAlignedSeriesWithAggregations(Map<PartialPath,List<Integer>> pathToAggrIndexesMap)
Copyright © 2022 The Apache Software Foundation. All rights reserved.