public class MaxTimeAggrResult extends AggregateResult
hasCandidateResult, resultDataType, TIME_LENGTH_FOR_FIRST_VALUE| 构造器和说明 |
|---|
MaxTimeAggrResult() |
| 限定符和类型 | 方法和说明 |
|---|---|
protected void |
deserializeSpecificFields(ByteBuffer buffer) |
Long |
getResult() |
boolean |
hasFinalResult()
Judge if aggregation results have been calculated.
|
void |
merge(AggregateResult another)
Merge another aggregateResult into this
|
protected void |
serializeSpecificFields(OutputStream outputStream) |
protected void |
updateMaxTimeResult(long value) |
void |
updateResultFromPageData(IBatchDataIterator batchIterator)
Aggregate results cannot be calculated using Statistics directly, using the data in each page.
|
void |
updateResultFromPageData(IBatchDataIterator batchIterator,
Predicate<Long> boundPredicate)
Aggregate results cannot be calculated using Statistics directly, using the data in each page.
|
void |
updateResultFromStatistics(Statistics statistics)
Calculate the aggregation using Statistics
|
void |
updateResultUsingTimestamps(long[] timestamps,
int length,
IReaderByTimestamp dataReader)
This method calculates the aggregation using common timestamps of the cross series filter.
|
void |
updateResultUsingValues(long[] timestamps,
int length,
ValueIterator valueIterator)
This method calculates the aggregation using values that have been calculated
|
deserializeFrom, getAggregationType, getBinaryValue, getBooleanValue, getDoubleValue, getFloatValue, getIntValue, getLongValue, getResultDataType, getValue, hasCandidateResult, isAscending, reset, serializeTo, setBinaryValue, setBooleanValue, setDoubleValue, setFloatValue, setIntValue, setLongValue, setValue, toStringpublic Long getResult()
getResult 在类中 AggregateResultpublic void updateResultFromStatistics(Statistics statistics)
AggregateResultupdateResultFromStatistics 在类中 AggregateResultstatistics - chunkStatistics or pageStatisticspublic void updateResultFromPageData(IBatchDataIterator batchIterator)
AggregateResultupdateResultFromPageData 在类中 AggregateResultbatchIterator - the data in Pagepublic void updateResultFromPageData(IBatchDataIterator batchIterator, Predicate<Long> boundPredicate)
AggregateResultupdateResultFromPageData 在类中 AggregateResultbatchIterator - the data in PageboundPredicate - used to judge whether the current timestamp is out of time range, returns
true if it is.public void updateResultUsingTimestamps(long[] timestamps,
int length,
IReaderByTimestamp dataReader)
throws IOException
AggregateResultupdateResultUsingTimestamps 在类中 AggregateResultIOException - TsFile data read errorpublic void updateResultUsingValues(long[] timestamps,
int length,
ValueIterator valueIterator)
AggregateResultupdateResultUsingValues 在类中 AggregateResultpublic boolean hasFinalResult()
AggregateResulthasFinalResult 在类中 AggregateResultpublic void merge(AggregateResult another)
AggregateResultmerge 在类中 AggregateResultprotected void deserializeSpecificFields(ByteBuffer buffer)
deserializeSpecificFields 在类中 AggregateResultprotected void serializeSpecificFields(OutputStream outputStream)
serializeSpecificFields 在类中 AggregateResultprotected void updateMaxTimeResult(long value)
Copyright © 2022 The Apache Software Foundation. All rights reserved.