public class MaxTimeDescAggrResult extends MaxTimeAggrResult
hasCandidateResult, resultDataType, TIME_LENGTH_FOR_FIRST_VALUE| 构造器和说明 |
|---|
MaxTimeDescAggrResult() |
| 限定符和类型 | 方法和说明 |
|---|---|
boolean |
hasFinalResult()
Judge if aggregation results have been calculated.
|
boolean |
isAscending()
Whether the AggregationResult accepts data in time ascending order, if it returns false, the
data should be passed in time descending order.
|
void |
updateResultFromPageData(IBatchDataIterator batchIterator,
Predicate<Long> boundPredicate)
Aggregate results cannot be calculated using Statistics directly, using the data in each page.
|
void |
updateResultFromStatistics(Statistics statistics)
Calculate the aggregation using Statistics
|
void |
updateResultUsingTimestamps(long[] timestamps,
int length,
IReaderByTimestamp dataReader)
This method calculates the aggregation using common timestamps of the cross series filter.
|
void |
updateResultUsingValues(long[] timestamps,
int length,
ValueIterator valueIterator)
This method calculates the aggregation using values that have been calculated
|
deserializeSpecificFields, getResult, merge, serializeSpecificFields, updateMaxTimeResult, updateResultFromPageDatadeserializeFrom, getAggregationType, getBinaryValue, getBooleanValue, getDoubleValue, getFloatValue, getIntValue, getLongValue, getResultDataType, getValue, hasCandidateResult, reset, serializeTo, setBinaryValue, setBooleanValue, setDoubleValue, setFloatValue, setIntValue, setLongValue, setValue, toStringpublic void updateResultFromStatistics(Statistics statistics)
AggregateResultupdateResultFromStatistics 在类中 MaxTimeAggrResultstatistics - chunkStatistics or pageStatisticspublic void updateResultFromPageData(IBatchDataIterator batchIterator, Predicate<Long> boundPredicate)
AggregateResultupdateResultFromPageData 在类中 MaxTimeAggrResultbatchIterator - the data in PageboundPredicate - used to judge whether the current timestamp is out of time range, returns
true if it is.public void updateResultUsingTimestamps(long[] timestamps,
int length,
IReaderByTimestamp dataReader)
throws IOException
AggregateResultupdateResultUsingTimestamps 在类中 MaxTimeAggrResultIOException - TsFile data read errorpublic void updateResultUsingValues(long[] timestamps,
int length,
ValueIterator valueIterator)
AggregateResultpublic boolean hasFinalResult()
AggregateResulthasFinalResult 在类中 MaxTimeAggrResultpublic boolean isAscending()
AggregateResultisAscending 在类中 AggregateResultCopyright © 2022 The Apache Software Foundation. All rights reserved.