| 程序包 | 说明 |
|---|---|
| org.apache.iotdb.db.engine.storagegroup | |
| org.apache.iotdb.db.query.control | |
| org.apache.iotdb.db.service.basic |
| 类和说明 |
|---|
| QueryFileManager
QueryFileManager records the paths of files that every query uses for QueryResourceManager.
|
| 类和说明 |
|---|
| FileReaderManager
FileReaderManager is a singleton, which is used to manage all file readers(opened file streams)
to ensure that each file is opened at most once.
|
| QueryFileManager
QueryFileManager records the paths of files that every query uses for QueryResourceManager.
|
| QueryResourceManager
QueryResourceManager manages resource (file streams) used by each query job, and assign Ids to
the jobs.
|
| QueryTimeManager
This class is used to monitor the executing time of each query.
|
| SessionManager |
| SessionTimeoutManager |
| 类和说明 |
|---|
| QueryTimeManager
This class is used to monitor the executing time of each query.
|
| SessionManager |
Copyright © 2022 The Apache Software Foundation. All rights reserved.