| 类 | 说明 |
|---|---|
| TracingConstant |
this class contains several constants used in Tracing.
|
| TracingInfo |
A distinct TracingInfo is storaged for each query id, which includes the total number of chunks,
the average points number of chunk, the information of sequence files and unSequence files this
query involves.
|
| TracingManager |
Copyright © 2022 The Apache Software Foundation. All rights reserved.