public interface IUDFInputDataSet
| 限定符和类型 | 方法和说明 |
|---|---|
List<TSDataType> |
getDataTypes()
returns the input data types, except the timestamp column(the last column).
|
boolean |
hasNextRowInObjects()
Whether the data set has next row.
|
Object[] |
nextRowInObjects()
Get the next row for UDFPlan input.
|
List<TSDataType> getDataTypes()
boolean hasNextRowInObjects()
throws IOException
IOExceptionObject[] nextRowInObjects() throws IOException
The last element in the row is the timestamp.
IOExceptionCopyright © 2022 The Apache Software Foundation. All rights reserved.