public class UDFInputDataSet extends Object implements IUDFInputDataSet
| 构造器和说明 |
|---|
UDFInputDataSet(QueryDataSet dataSet,
List<TSDataType> dataTypes) |
| 限定符和类型 | 方法和说明 |
|---|---|
List<TSDataType> |
getDataTypes()
returns the input data types, except the timestamp column(the last column).
|
boolean |
hasNextRowInObjects()
Whether the data set has next row.
|
Object[] |
nextRowInObjects()
Get the next row for UDFPlan input.
|
public UDFInputDataSet(QueryDataSet dataSet, List<TSDataType> dataTypes)
public List<TSDataType> getDataTypes()
IUDFInputDataSetgetDataTypes 在接口中 IUDFInputDataSetpublic boolean hasNextRowInObjects()
throws IOException
IUDFInputDataSethasNextRowInObjects 在接口中 IUDFInputDataSetIOExceptionpublic Object[] nextRowInObjects() throws IOException
IUDFInputDataSetThe last element in the row is the timestamp.
nextRowInObjects 在接口中 IUDFInputDataSetIOExceptionCopyright © 2022 The Apache Software Foundation. All rights reserved.