public class UDTFNonAlignDataSet extends UDTFDataSet implements DirectNonAlignDataSet
QueryDataSet.EndPoint| 限定符和类型 | 字段和说明 |
|---|---|
protected int[] |
alreadyReturnedRowNumArray |
protected boolean |
isInitialized |
protected int[] |
offsetArray |
queryId, rawQueryInputLayer, transformers, UDF_COLLECTOR_MEMORY_BUDGET_IN_MB, UDF_READER_MEMORY_BUDGET_IN_MB, UDF_TRANSFORMER_MEMORY_BUDGET_IN_MB, udtfPlanalreadyReturnedRowNum, ascending, columnNum, dataTypes, endPoint, fetchSize, paths, rowLimit, rowOffset, withoutAllNull, withoutAnyNull, withoutNullColumnsIndex| 构造器和说明 |
|---|
UDTFNonAlignDataSet(QueryContext context,
UDTFPlan udtfPlan,
List<ManagedSeriesReader> readersOfSelectedSeries)
execute without value filter
|
UDTFNonAlignDataSet(QueryContext context,
UDTFPlan udtfPlan,
TimeGenerator timestampGenerator,
List<IReaderByTimestamp> readersOfSelectedSeries,
List<List<Integer>> readerToIndexList,
List<Boolean> cached)
execute with value filter
|
| 限定符和类型 | 方法和说明 |
|---|---|
org.apache.iotdb.service.rpc.thrift.TSQueryNonAlignDataSet |
fillBuffer(int fetchSize,
WatermarkEncoder encoder) |
protected Pair<ByteBuffer,ByteBuffer> |
fillColumnBuffer(int transformedDataColumnIndex,
int fetchSize,
WatermarkEncoder encoder) |
boolean |
hasNextWithoutConstraint() |
protected void |
init()
offsetArray can not be initialized in the constructor, because rowOffset is set after the
DataSet's construction. note that this method only can be called once in a query.
|
RowRecord |
nextWithoutConstraint() |
finalizeUDFs, initTransformersdecreaseAlreadyReturnedRowNum, getColumnNum, getDataTypes, getEndPoint, getPaths, getRowLimit, getRowOffset, getWithoutNullColumnsIndex, hasLimit, hasNext, initQueryDataSetFields, isWithoutAllNull, isWithoutAnyNull, next, setColumnNum, setDataTypes, setEndPoint, setFetchSize, setRowLimit, setRowOffset, setWithoutAllNull, setWithoutAnyNull, setWithoutNullColumnsIndex, withoutNullFilterprotected boolean isInitialized
protected int[] alreadyReturnedRowNumArray
protected int[] offsetArray
public UDTFNonAlignDataSet(QueryContext context, UDTFPlan udtfPlan, TimeGenerator timestampGenerator, List<IReaderByTimestamp> readersOfSelectedSeries, List<List<Integer>> readerToIndexList, List<Boolean> cached) throws IOException, QueryProcessException
public UDTFNonAlignDataSet(QueryContext context, UDTFPlan udtfPlan, List<ManagedSeriesReader> readersOfSelectedSeries) throws QueryProcessException, IOException, InterruptedException
protected void init()
public org.apache.iotdb.service.rpc.thrift.TSQueryNonAlignDataSet fillBuffer(int fetchSize,
WatermarkEncoder encoder)
throws IOException,
QueryProcessException
fillBuffer 在接口中 DirectNonAlignDataSetIOExceptionQueryProcessExceptionprotected Pair<ByteBuffer,ByteBuffer> fillColumnBuffer(int transformedDataColumnIndex, int fetchSize, WatermarkEncoder encoder) throws IOException, QueryProcessException
public boolean hasNextWithoutConstraint()
hasNextWithoutConstraint 在类中 QueryDataSetpublic RowRecord nextWithoutConstraint()
nextWithoutConstraint 在类中 QueryDataSetCopyright © 2022 The Apache Software Foundation. All rights reserved.