public abstract class BinaryExpression extends Expression
| 限定符和类型 | 字段和说明 |
|---|---|
protected Expression |
leftExpression |
protected Expression |
rightExpression |
isConstantOperandCache| 限定符 | 构造器和说明 |
|---|---|
protected |
BinaryExpression(Expression leftExpression,
Expression rightExpression) |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
collectPaths(Set<PartialPath> pathSet) |
void |
concat(List<PartialPath> prefixPaths,
List<Expression> resultExpressions) |
IntermediateLayer |
constructIntermediateLayer(long queryId,
UDTFPlan udtfPlan,
RawQueryInputLayer rawTimeSeriesInputLayer,
Map<Expression,IntermediateLayer> expressionIntermediateLayerMap,
Map<Expression,TSDataType> expressionDataTypeMap,
LayerMemoryAssigner memoryAssigner) |
protected abstract ArithmeticBinaryTransformer |
constructTransformer(LayerPointReader leftParentLayerPointReader,
LayerPointReader rightParentLayerPointReader) |
void |
constructUdfExecutors(Map<String,UDTFExecutor> expressionName2Executor,
ZoneId zoneId) |
List<Expression> |
getExpressions()
returns the DIRECT children expressions if it has any, otherwise an EMPTY list will be returned
|
String |
getExpressionStringInternal()
Sub-classes should override this method to provide valid string representation of this object.
|
Expression |
getLeftExpression() |
Expression |
getRightExpression() |
boolean |
isConstantOperandInternal()
Sub-classes should override this method indicating if the expression is a constant operand
|
boolean |
isTimeSeriesGeneratingFunctionExpression() |
boolean |
isUserDefinedAggregationFunctionExpression() |
protected abstract String |
operator() |
void |
removeWildcards(WildcardsRemover wildcardsRemover,
List<Expression> resultExpressions) |
void |
updateStatisticsForMemoryAssigner(LayerMemoryAssigner memoryAssigner) |
equals, getExpressionString, hashCode, isConstantOperand, isPlainAggregationFunctionExpression, iterator, toStringprotected final Expression leftExpression
protected final Expression rightExpression
protected BinaryExpression(Expression leftExpression, Expression rightExpression)
public Expression getLeftExpression()
public Expression getRightExpression()
public boolean isConstantOperandInternal()
ExpressionisConstantOperandInternal 在类中 Expressionpublic boolean isTimeSeriesGeneratingFunctionExpression()
public boolean isUserDefinedAggregationFunctionExpression()
public List<Expression> getExpressions()
ExpressiongetExpressions 在类中 Expressionpublic final void concat(List<PartialPath> prefixPaths, List<Expression> resultExpressions)
concat 在类中 Expressionpublic final void removeWildcards(WildcardsRemover wildcardsRemover, List<Expression> resultExpressions) throws LogicalOptimizeException
removeWildcards 在类中 ExpressionLogicalOptimizeExceptionpublic void collectPaths(Set<PartialPath> pathSet)
collectPaths 在类中 Expressionpublic void constructUdfExecutors(Map<String,UDTFExecutor> expressionName2Executor, ZoneId zoneId)
constructUdfExecutors 在类中 Expressionpublic void updateStatisticsForMemoryAssigner(LayerMemoryAssigner memoryAssigner)
public IntermediateLayer constructIntermediateLayer(long queryId, UDTFPlan udtfPlan, RawQueryInputLayer rawTimeSeriesInputLayer, Map<Expression,IntermediateLayer> expressionIntermediateLayerMap, Map<Expression,TSDataType> expressionDataTypeMap, LayerMemoryAssigner memoryAssigner) throws QueryProcessException, IOException
protected abstract ArithmeticBinaryTransformer constructTransformer(LayerPointReader leftParentLayerPointReader, LayerPointReader rightParentLayerPointReader)
public final String getExpressionStringInternal()
ExpressionExpression.getExpressionString()getExpressionStringInternal 在类中 Expressionprotected abstract String operator()
Copyright © 2022 The Apache Software Foundation. All rights reserved.