public class FunctionExpression extends Expression
isConstantOperandCache| 构造器和说明 |
|---|
FunctionExpression(String functionName) |
FunctionExpression(String functionName,
Map<String,String> functionAttributes,
List<Expression> expressions) |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
addAttribute(String key,
String value) |
void |
addExpression(Expression expression) |
void |
collectPaths(Set<PartialPath> pathSet) |
void |
concat(List<PartialPath> prefixPaths,
List<Expression> resultExpressions) |
IntermediateLayer |
constructIntermediateLayer(long queryId,
UDTFPlan udtfPlan,
RawQueryInputLayer rawTimeSeriesInputLayer,
Map<Expression,IntermediateLayer> expressionIntermediateLayerMap,
Map<Expression,TSDataType> expressionDataTypeMap,
LayerMemoryAssigner memoryAssigner) |
void |
constructUdfExecutors(Map<String,UDTFExecutor> expressionName2Executor,
ZoneId zoneId) |
List<Expression> |
getExpressions()
returns the DIRECT children expressions if it has any, otherwise an EMPTY list will be returned
|
String |
getExpressionStringInternal()
Sub-classes should override this method to provide valid string representation of this object.
|
Map<String,String> |
getFunctionAttributes() |
String |
getFunctionName() |
List<PartialPath> |
getPaths() |
boolean |
isConstantOperandInternal()
Sub-classes should override this method indicating if the expression is a constant operand
|
boolean |
isCountStar() |
boolean |
isPlainAggregationFunctionExpression() |
boolean |
isTimeSeriesGeneratingFunctionExpression() |
boolean |
isUserDefinedAggregationFunctionExpression() |
void |
removeWildcards(WildcardsRemover wildcardsRemover,
List<Expression> resultExpressions) |
void |
setExpressions(List<Expression> expressions) |
void |
updateStatisticsForMemoryAssigner(LayerMemoryAssigner memoryAssigner) |
equals, getExpressionString, hashCode, isConstantOperand, iterator, toStringpublic FunctionExpression(String functionName)
public boolean isPlainAggregationFunctionExpression()
public boolean isConstantOperandInternal()
ExpressionisConstantOperandInternal 在类中 Expressionpublic boolean isTimeSeriesGeneratingFunctionExpression()
public boolean isUserDefinedAggregationFunctionExpression()
public boolean isCountStar()
public void addExpression(Expression expression)
public void setExpressions(List<Expression> expressions)
public String getFunctionName()
public List<Expression> getExpressions()
ExpressiongetExpressions 在类中 Expressionpublic void concat(List<PartialPath> prefixPaths, List<Expression> resultExpressions)
concat 在类中 Expressionpublic void removeWildcards(WildcardsRemover wildcardsRemover, List<Expression> resultExpressions) throws LogicalOptimizeException
removeWildcards 在类中 ExpressionLogicalOptimizeExceptionpublic void collectPaths(Set<PartialPath> pathSet)
collectPaths 在类中 Expressionpublic void constructUdfExecutors(Map<String,UDTFExecutor> expressionName2Executor, ZoneId zoneId)
constructUdfExecutors 在类中 Expressionpublic void updateStatisticsForMemoryAssigner(LayerMemoryAssigner memoryAssigner)
public IntermediateLayer constructIntermediateLayer(long queryId, UDTFPlan udtfPlan, RawQueryInputLayer rawTimeSeriesInputLayer, Map<Expression,IntermediateLayer> expressionIntermediateLayerMap, Map<Expression,TSDataType> expressionDataTypeMap, LayerMemoryAssigner memoryAssigner) throws QueryProcessException, IOException
public List<PartialPath> getPaths()
public String getExpressionStringInternal()
ExpressionExpression.getExpressionString()getExpressionStringInternal 在类中 ExpressionCopyright © 2022 The Apache Software Foundation. All rights reserved.