public class DiskChunkReaderByTimestamp extends Object implements IReaderByTimestamp
IReaderByTimestamp based on the data reader ChunkReaderByTimestamp.
| 构造器和说明 |
|---|
DiskChunkReaderByTimestamp(ChunkReaderByTimestamp chunkReaderByTimestamp) |
| 限定符和类型 | 方法和说明 |
|---|---|
Object[] |
getValuesInTimestamps(long[] timestamps,
int length)
Returns the corresponding value under this timestamp.
|
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitreaderIsEmptypublic DiskChunkReaderByTimestamp(ChunkReaderByTimestamp chunkReaderByTimestamp)
public Object[] getValuesInTimestamps(long[] timestamps, int length) throws IOException
IReaderByTimestampNote that calling this method will change the status of this reader irreversibly just like
next. The difference is that next moves one step forward while
getValueInTimestamp advances towards the given timestamp.
Attention: DO call this method with monotonically increasing timestamps. There is no guarantee of correctness with any other way of calling. For example, DO NOT call this method twice with the same timestamp.
getValuesInTimestamps 在接口中 IReaderByTimestampIOExceptionCopyright © 2022 The Apache Software Foundation. All rights reserved.