public class SeriesReaderByTimestamp extends Object implements IReaderByTimestamp
| 构造器和说明 |
|---|
SeriesReaderByTimestamp(PartialPath seriesPath,
Set<String> allSensors,
TSDataType dataType,
QueryContext context,
List<TsFileResource> seqFileResource,
List<TsFileResource> unseqFileResource,
boolean ascending) |
SeriesReaderByTimestamp(PartialPath seriesPath,
Set<String> allSensors,
TSDataType dataType,
QueryContext context,
QueryDataSource dataSource,
TsFileFilter fileFilter,
boolean ascending) |
SeriesReaderByTimestamp(SeriesReader seriesReader,
boolean ascending) |
| 限定符和类型 | 方法和说明 |
|---|---|
Object[] |
getValuesInTimestamps(long[] timestamps,
int length)
Returns the corresponding value under this timestamp.
|
protected boolean |
hasNext(long timestamp) |
boolean |
readerIsEmpty()
Returns whether there is no more data in reader.
|
public SeriesReaderByTimestamp(PartialPath seriesPath, Set<String> allSensors, TSDataType dataType, QueryContext context, QueryDataSource dataSource, TsFileFilter fileFilter, boolean ascending)
public SeriesReaderByTimestamp(SeriesReader seriesReader, boolean ascending)
public SeriesReaderByTimestamp(PartialPath seriesPath, Set<String> allSensors, TSDataType dataType, QueryContext context, List<TsFileResource> seqFileResource, List<TsFileResource> unseqFileResource, boolean ascending)
public Object[] getValuesInTimestamps(long[] timestamps, int length) throws IOException
IReaderByTimestampNote that calling this method will change the status of this reader irreversibly just like
next. The difference is that next moves one step forward while
getValueInTimestamp advances towards the given timestamp.
Attention: DO call this method with monotonically increasing timestamps. There is no guarantee of correctness with any other way of calling. For example, DO NOT call this method twice with the same timestamp.
getValuesInTimestamps 在接口中 IReaderByTimestampIOExceptionpublic boolean readerIsEmpty()
throws IOException
IReaderByTimestampTrue means no more data. False means you can still get more data
readerIsEmpty 在接口中 IReaderByTimestampIOExceptionprotected boolean hasNext(long timestamp)
throws IOException
IOExceptionCopyright © 2022 The Apache Software Foundation. All rights reserved.