public class PrimitiveArrayManager extends Object
| 限定符和类型 | 字段和说明 |
|---|---|
static int |
ARRAY_SIZE |
| 限定符和类型 | 方法和说明 |
|---|---|
static Object |
allocate(TSDataType dataType)
Get or allocate primitive data lists according to type.
|
static void |
close() |
static Object |
createDataListsByType(TSDataType dataType,
int size)
Get primitive data lists according to data type and size, only for TVList's sorting
|
static int |
getArrayRowCount(int size) |
static void |
release(Object array)
This method is called when bringing back data array
|
public static Object allocate(TSDataType dataType)
public static void release(Object array)
array - data array to be releasedpublic static void close()
public static Object createDataListsByType(TSDataType dataType, int size)
dataType - data typesize - needed capacitypublic static int getArrayRowCount(int size)
Copyright © 2022 The Apache Software Foundation. All rights reserved.