public interface ILoadLogger
| 限定符和类型 | 字段和说明 |
|---|---|
static String |
LOAD_DELETED_FILE_NAME_START |
static String |
LOAD_TSFILE_START |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
close() |
void |
finishLoadDeletedFile(File file)
After a deleted file is loaded, record it in load log.
|
void |
finishLoadTsfile(File file)
After a new tsfile is loaded, record it in load log.
|
void |
startLoadDeletedFiles()
Start to load deleted files.
|
void |
startLoadTsFiles()
Start to load tsfiles
|
void startLoadDeletedFiles()
throws IOException
IOExceptionvoid finishLoadDeletedFile(File file) throws IOException
file - deleted file to be loadedIOExceptionvoid startLoadTsFiles()
throws IOException
IOExceptionvoid finishLoadTsfile(File file) throws IOException
file - new tsfile to be loadedIOExceptionvoid close()
throws IOException
IOExceptionCopyright © 2022 The Apache Software Foundation. All rights reserved.