public class LoadLogger extends Object implements ILoadLogger
LOAD_DELETED_FILE_NAME_START, LOAD_TSFILE_START| 构造器和说明 |
|---|
LoadLogger(File logFile) |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
close() |
void |
finishLoadDeletedFile(File file)
After a deleted file is loaded, record it in load log.
|
void |
finishLoadTsfile(File file)
After a new tsfile is loaded, record it in load log.
|
void |
startLoadDeletedFiles()
Start to load deleted files.
|
void |
startLoadTsFiles()
Start to load tsfiles
|
public LoadLogger(File logFile) throws IOException
IOExceptionpublic void startLoadDeletedFiles()
throws IOException
ILoadLoggerstartLoadDeletedFiles 在接口中 ILoadLoggerIOExceptionpublic void finishLoadDeletedFile(File file) throws IOException
ILoadLoggerfinishLoadDeletedFile 在接口中 ILoadLoggerfile - deleted file to be loadedIOExceptionpublic void startLoadTsFiles()
throws IOException
ILoadLoggerstartLoadTsFiles 在接口中 ILoadLoggerIOExceptionpublic void finishLoadTsfile(File file) throws IOException
ILoadLoggerfinishLoadTsfile 在接口中 ILoadLoggerfile - new tsfile to be loadedIOExceptionpublic void close()
throws IOException
close 在接口中 ILoadLoggerIOExceptionCopyright © 2022 The Apache Software Foundation. All rights reserved.