public interface ISyncFileManager
| 限定符和类型 | 方法和说明 |
|---|---|
Map<String,Map<Long,Set<Long>>> |
getAllSGs() |
void |
getCurrentLocalFiles(String dataDir)
Find out all closed and unmodified files, which means there has a .resource file and doesn't
have a .mod file and .merge file.
|
Map<String,Map<Long,Map<Long,Set<File>>>> |
getCurrentSealedLocalFilesMap() |
Map<String,Map<Long,Map<Long,Set<File>>>> |
getDeletedFilesMap() |
void |
getLastLocalFiles(File lastLocalFile)
Load last local files from file
|
Map<String,Map<Long,Map<Long,Set<File>>>> |
getLastLocalFilesMap() |
Map<String,Map<Long,Map<Long,Set<File>>>> |
getToBeSyncedFilesMap() |
void |
getValidFiles(String dataDir)
Based on current local files and last local files, we can distinguish two kinds of files
between them, one is deleted files, the other is new files.
|
void getCurrentLocalFiles(String dataDir)
dataDir - data directoryvoid getLastLocalFiles(File lastLocalFile) throws IOException
lastLocalFile - last local file, which may not exist in first sync task.IOExceptionvoid getValidFiles(String dataDir) throws IOException
dataDir - data directoryIOExceptionMap<String,Map<Long,Map<Long,Set<File>>>> getCurrentSealedLocalFilesMap()
Copyright © 2022 The Apache Software Foundation. All rights reserved.