public class SyncFileManager extends Object implements ISyncFileManager
| 限定符和类型 | 方法和说明 |
|---|---|
Map<String,Map<Long,Set<Long>>> |
getAllSGs() |
void |
getCurrentLocalFiles(String dataDir)
Find out all closed and unmodified files, which means there has a .resource file and doesn't
have a .mod file and .merge file.
|
Map<String,Map<Long,Map<Long,Set<File>>>> |
getCurrentSealedLocalFilesMap() |
Map<String,Map<Long,Map<Long,Set<File>>>> |
getDeletedFilesMap() |
static SyncFileManager |
getInstance() |
void |
getLastLocalFiles(File lastLocalFileInfo)
Load last local files from file
|
Map<String,Map<Long,Map<Long,Set<File>>>> |
getLastLocalFilesMap() |
Map<String,Map<Long,Map<Long,Set<File>>>> |
getToBeSyncedFilesMap() |
void |
getValidFiles(String dataDir)
Based on current local files and last local files, we can distinguish two kinds of files
between them, one is deleted files, the other is new files.
|
public static SyncFileManager getInstance()
public void getCurrentLocalFiles(String dataDir)
ISyncFileManagergetCurrentLocalFiles 在接口中 ISyncFileManagerdataDir - data directorypublic void getLastLocalFiles(File lastLocalFileInfo) throws IOException
ISyncFileManagergetLastLocalFiles 在接口中 ISyncFileManagerlastLocalFileInfo - last local file, which may not exist in first sync task.IOExceptionpublic void getValidFiles(String dataDir) throws IOException
ISyncFileManagergetValidFiles 在接口中 ISyncFileManagerdataDir - data directoryIOExceptionpublic Map<String,Map<Long,Map<Long,Set<File>>>> getCurrentSealedLocalFilesMap()
public Map<String,Map<Long,Map<Long,Set<File>>>> getLastLocalFilesMap()
getLastLocalFilesMap 在接口中 ISyncFileManagerpublic Map<String,Map<Long,Map<Long,Set<File>>>> getDeletedFilesMap()
getDeletedFilesMap 在接口中 ISyncFileManagerpublic Map<String,Map<Long,Map<Long,Set<File>>>> getToBeSyncedFilesMap()
getToBeSyncedFilesMap 在接口中 ISyncFileManagerCopyright © 2022 The Apache Software Foundation. All rights reserved.