| 类 | 说明 |
|---|---|
| IoTDBDataDirViewer | |
| TsFileResourcePrinter |
This tool can analyze the tsfile.resource files from a folder, or analyze a single
tsfile.resource file.
|
| TsFileRewriteTool | |
| TsFileSelfCheckTool | |
| TsFileSketchTool | |
| TsFileSplitTool | |
| WalChecker |
WalChecker verifies that whether all insert ahead logs in the WAL folder are recognizable.
|
Copyright © 2022 The Apache Software Foundation. All rights reserved.