| 类 | 说明 |
|---|---|
| DeviceMappingViewer |
for DBA to view the mapping from device to virtual storage group ID usage: run this class with
arguments [system_schema_dir], if args are not given, use default in config
|
Copyright © 2022 The Apache Software Foundation. All rights reserved.