public class MemUtils extends Object
| 限定符和类型 | 方法和说明 |
|---|---|
static String |
bytesCntToStr(long inputCnt)
function for converting the byte count result to readable string.
|
static long |
getAlignedRecordsSize(List<TSDataType> dataTypes,
Object[] value,
boolean addingTextDataSize)
function for getting the vector value size.
|
static long |
getAlignedTabletSize(InsertTabletPlan insertTabletPlan,
int start,
int end,
boolean addingTextDataSize) |
static long |
getBinaryColumnSize(Binary[] column,
int start,
int end) |
static long |
getBinarySize(Binary value) |
static long |
getDataPointMem(DataPoint dataPoint)
function for getting the memory size of the given data point.
|
static long |
getRecordSize(TSDataType dataType,
Object value,
boolean addingTextDataSize)
function for getting the value size.
|
static long |
getRecordsSize(List<TSDataType> dataTypes,
Object[] value,
boolean addingTextDataSize)
function for getting the value size.
|
static long |
getStringMem(String str)
function for getting the memory size of the given string.
|
static long |
getTabletSize(InsertTabletPlan insertTabletPlan,
int start,
int end,
boolean addingTextDataSize)
If mem control enabled, do not add text data size here, the size will be added to memtable
before inserting.
|
static long |
getTsRecordMem(TSRecord record)
Calculate how much memory will be used if the given record is written to sequence file.
|
public static long getRecordSize(TSDataType dataType, Object value, boolean addingTextDataSize)
public static long getRecordsSize(List<TSDataType> dataTypes, Object[] value, boolean addingTextDataSize)
public static long getAlignedRecordsSize(List<TSDataType> dataTypes, Object[] value, boolean addingTextDataSize)
public static long getBinarySize(Binary value)
public static long getBinaryColumnSize(Binary[] column, int start, int end)
public static long getTabletSize(InsertTabletPlan insertTabletPlan, int start, int end, boolean addingTextDataSize)
public static long getAlignedTabletSize(InsertTabletPlan insertTabletPlan, int start, int end, boolean addingTextDataSize)
public static long getTsRecordMem(TSRecord record)
public static long getStringMem(String str)
public static long getDataPointMem(DataPoint dataPoint)
public static String bytesCntToStr(long inputCnt)
Copyright © 2022 The Apache Software Foundation. All rights reserved.