public class SchemaUtils extends Object
| 限定符和类型 | 方法和说明 |
|---|---|
static void |
cacheTimeseriesSchema(TimeseriesSchema schema) |
static void |
checkDataTypeWithEncoding(TSDataType dataType,
TSEncoding encoding) |
static Throwable |
findMetaMissingException(Throwable currEx)
If e or one of its recursive causes is a PathNotExistException or StorageGroupNotSetException,
return such an exception or null if it cannot be found.
|
static List<TSDataType> |
getAggregatedDataTypes(List<TSDataType> measurementDataType,
String aggregation)
If the datatype of 'aggregation' depends on 'measurementDataType' (min_value, max_value),
return 'measurementDataType' directly, or return a list whose elements are all the datatype of
'aggregation' and its length is the same as 'measurementDataType'.
|
static TSDataType |
getAggregationType(String aggregation) |
static TSDataType |
getSeriesTypeByPath(MeasurementPath path,
String aggregation) |
static List<TSDataType> |
getSeriesTypesByPaths(Collection<? extends PartialPath> paths) |
static List<TSDataType> |
getSeriesTypesByPaths(List<MeasurementPath> paths,
List<String> aggregations) |
static void |
registerTimeseries(TimeseriesSchema schema) |
public static void registerTimeseries(TimeseriesSchema schema)
public static void cacheTimeseriesSchema(TimeseriesSchema schema)
public static List<TSDataType> getSeriesTypesByPaths(Collection<? extends PartialPath> paths)
public static List<TSDataType> getAggregatedDataTypes(List<TSDataType> measurementDataType, String aggregation)
measurementDataType - aggregation - public static List<TSDataType> getSeriesTypesByPaths(List<MeasurementPath> paths, List<String> aggregations)
public static TSDataType getSeriesTypeByPath(MeasurementPath path, String aggregation)
public static TSDataType getAggregationType(String aggregation)
aggregation - aggregation functionpublic static Throwable findMetaMissingException(Throwable currEx)
currEx - public static void checkDataTypeWithEncoding(TSDataType dataType, TSEncoding encoding) throws MetadataException
Copyright © 2022 The Apache Software Foundation. All rights reserved.