public class SyncUtils extends Object
| 限定符和类型 | 方法和说明 |
|---|---|
static File |
getSnapshotFile(File file)
This method is to get a snapshot file seriesPath according to a tsfile seriesPath.
|
static boolean |
isEmpty(Map<String,Map<Long,Map<Long,Set<File>>>> sendingFileList)
Verify sending list is empty or not It's used by sync sender.
|
static boolean |
verifyIPSegment(String ipWhiteList,
String ipAddress)
Verify IP address with IP white list which contains more than one IP segment.
|
public static File getSnapshotFile(File file)
public static boolean isEmpty(Map<String,Map<Long,Map<Long,Set<File>>>> sendingFileList)
Copyright © 2022 The Apache Software Foundation. All rights reserved.