public class SingleFileLogReader extends Object implements ILogReader
| 限定符和类型 | 字段和说明 |
|---|---|
static int |
LEAST_LOG_SIZE |
| 构造器和说明 |
|---|
SingleFileLogReader(File logFile) |
| 限定符和类型 | 方法和说明 |
|---|---|
void |
close()
release resources occupied by this object, like file streams.
|
boolean |
hasNext()
return whether there exists next log to be read.
|
boolean |
isFileCorrupted() |
PhysicalPlan |
next()
return the next log read from media like a WAL file and covert it to a PhysicalPlan.
|
void |
open(File logFile) |
public static final int LEAST_LOG_SIZE
public SingleFileLogReader(File logFile) throws FileNotFoundException
public boolean hasNext()
ILogReaderhasNext 在接口中 ILogReaderpublic PhysicalPlan next()
ILogReadernext 在接口中 ILogReaderpublic void close()
ILogReaderclose 在接口中 ILogReaderpublic void open(File logFile) throws FileNotFoundException
public boolean isFileCorrupted()
Copyright © 2022 The Apache Software Foundation. All rights reserved.