public interface WriteLogNode
| 限定符和类型 | 方法和说明 |
|---|---|
void |
close()
Sync and close streams.
|
ByteBuffer[] |
delete()
Abandon all logs in this node and delete the log directory.
|
void |
forceSync()
Write what in cache to disk.
|
String |
getIdentifier()
return identifier of the log node.
|
String |
getLogDirectory()
return the directory where wal files of this node are placed.
|
ILogReader |
getLogReader()
return an ILogReader which can iterate each log in this log node.
|
void |
initBuffer(ByteBuffer[] byteBuffers)
init the buffers, this should be called after this node being created.
|
void |
notifyEndFlush()
When data that have WALs in this node end flushing, this method must be called to check and
remove the out-dated logs file.
|
void |
notifyStartFlush()
When data that have WALs in this node start to be flushed, this method must be called to change
the working WAL file.
|
void |
release()
Release the resource it occupies.
|
void |
write(PhysicalPlan plan)
Write a wal for a PhysicalPlan.
|
void write(PhysicalPlan plan) throws IOException
plan - - a PhysicalPlanIOExceptionvoid close()
throws IOException
IOExceptionvoid release()
void forceSync()
throws IOException
IOExceptionvoid notifyStartFlush()
throws IOException
IOExceptionvoid notifyEndFlush()
String getIdentifier()
String getLogDirectory()
ByteBuffer[] delete() throws IOException
IOExceptionILogReader getLogReader()
void initBuffer(ByteBuffer[] byteBuffers)
Copyright © 2022 The Apache Software Foundation. All rights reserved.